@@ -10,6 +10,7 @@
 """
 
 from pycatia.system_interfaces.any_object import AnyObject
+from pycatia.types import cat_variant
 
 
 class DrawingComponent(AnyObject):
@@ -34,7 +35,7 @@ class DrawingComponent(AnyObject):
         self.drawing_component = com_object
 
     @property
-    def angle(self):
+    def angle(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -55,12 +56,13 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.Angle = Angle90Clockwise
 
         :return: float
+        :rtype: float
         """
 
         return self.drawing_component.Angle
 
     @angle.setter
-    def angle(self, value):
+    def angle(self, value: float):
         """
         :param float value:
         """
@@ -68,7 +70,7 @@ class DrawingComponent(AnyObject):
         self.drawing_component.Angle = value
 
     @property
-    def comp_ref(self):
+    def comp_ref(self) -> 'DrawingView':
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -85,12 +87,13 @@ class DrawingComponent(AnyObject):
                 |          Set ComponentRef = MyComponent.CompRef
 
         :return: DrawingView
+        :rtype: DrawingView
         """
         from pycatia.drafting_interfaces.drawing_view import DrawingView
         return DrawingView(self.drawing_component.CompRef)
 
     @property
-    def scale2(self):
+    def scale2(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -106,12 +109,13 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.Scale2 = 0.5
 
         :return: float
+        :rtype: float
         """
 
         return self.drawing_component.Scale2
 
     @scale2.setter
-    def scale2(self, value):
+    def scale2(self, value: float):
         """
         :param float value:
         """
@@ -119,7 +123,7 @@ class DrawingComponent(AnyObject):
         self.drawing_component.Scale2 = value
 
     @property
-    def x(self):
+    def x(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -138,12 +142,13 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.x =  NewXCoordinate
 
         :return: float
+        :rtype: float
         """
 
         return self.drawing_component.x
 
     @x.setter
-    def x(self, value):
+    def x(self, value: float):
         """
         :param float value:
         """
@@ -151,7 +156,7 @@ class DrawingComponent(AnyObject):
         self.drawing_component.x = value
 
     @property
-    def y(self):
+    def y(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -170,19 +175,20 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.y =  NewYCoordinate
 
         :return: float
+        :rtype: float
         """
 
         return self.drawing_component.y
 
     @y.setter
-    def y(self, value):
+    def y(self, value: float):
         """
         :param float value:
         """
 
         self.drawing_component.y = value
 
-    def explode(self):
+    def explode(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -203,10 +209,11 @@ class DrawingComponent(AnyObject):
                 |          MySelection.delete
 
         :return: None
+        :rtype: None
         """
         return self.drawing_component.Explode()
 
-    def explode_and_select(self):
+    def explode_and_select(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -223,10 +230,11 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.ExplodeAndSelect
 
         :return: None
+        :rtype: None
         """
         return self.drawing_component.ExplodeAndSelect()
 
-    def expose_comp_ref(self):
+    def expose_comp_ref(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -242,10 +250,11 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.ExposeCompRef
 
         :return: None
+        :rtype: None
         """
         return self.drawing_component.ExposeCompRef()
 
-    def expose_comp_ref_in_sheet(self, i_sheet):
+    def expose_comp_ref_in_sheet(self, i_sheet: 'DrawingSheet') -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -271,6 +280,7 @@ class DrawingComponent(AnyObject):
 
         :param DrawingSheet i_sheet:
         :return: None
+        :rtype: None
         """
         return self.drawing_component.ExposeCompRefInSheet(i_sheet.com_object)
         # # # # Autogenerated comment: 
@@ -289,7 +299,7 @@ class DrawingComponent(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def flip(self):
+    def flip(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -306,10 +316,11 @@ class DrawingComponent(AnyObject):
                 |          MyComponent.Flip
 
         :return: None
+        :rtype: None
         """
         return self.drawing_component.Flip()
 
-    def get_flip(self):
+    def get_flip(self) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -325,10 +336,11 @@ class DrawingComponent(AnyObject):
                 |          IsFlipped = MyComponent.GetFlip
 
         :return: bool
+        :rtype: bool
         """
         return self.drawing_component.GetFlip()
 
-    def get_matrix(self, io_matrix):
+    def get_matrix(self, io_matrix: tuple) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -356,6 +368,7 @@ class DrawingComponent(AnyObject):
 
         :param tuple io_matrix:
         :return: None
+        :rtype: None
         """
         return self.drawing_component.GetMatrix(io_matrix)
         # # # # Autogenerated comment: 
@@ -374,7 +387,7 @@ class DrawingComponent(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_modifiable_object(self, i_index):
+    def get_modifiable_object(self, i_index: cat_variant) -> AnyObject:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -389,12 +402,13 @@ class DrawingComponent(AnyObject):
                 | 
                 |          Object = MyComponent.GetModifiableObject(1)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: AnyObject
+        :rtype: AnyObject
         """
-        return AnyObject(self.drawing_component.GetModifiableObject(i_index))
+        return AnyObject(self.drawing_component.GetModifiableObject(i_index.com_object))
 
-    def get_modifiable_objects_count(self):
+    def get_modifiable_objects_count(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -410,10 +424,11 @@ class DrawingComponent(AnyObject):
                 |          Count = MyComponent.GetModifiableObjectsCount
 
         :return: int
+        :rtype: int
         """
         return self.drawing_component.GetModifiableObjectsCount()
 
-    def set_matrix(self, i_matrix):
+    def set_matrix(self, i_matrix: tuple) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -441,6 +456,7 @@ class DrawingComponent(AnyObject):
 
         :param tuple i_matrix:
         :return: None
+        :rtype: None
         """
         return self.drawing_component.SetMatrix(i_matrix)
         # # # # Autogenerated comment: 
