@@ -11,6 +11,7 @@
 
 from pycatia.drafting_interfaces.drawing_component import DrawingComponent
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class DrawingComponents(Collection):
@@ -34,7 +35,7 @@ class DrawingComponents(Collection):
         super().__init__(com_object, child_object=DrawingComponent)
         self.drawing_components = com_object
 
-    def add(self, i_drawing_component_ref, i_position_x, i_position_y):
+    def add(self, i_drawing_component_ref: 'DrawingView', i_position_x: float, i_position_y: float) -> DrawingComponent:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -77,6 +78,7 @@ class DrawingComponents(Collection):
         :param float i_position_x:
         :param float i_position_y:
         :return: DrawingComponent
+        :rtype: DrawingComponent
         """
         return DrawingComponent(
             self.drawing_components.Add(
@@ -86,7 +88,7 @@ class DrawingComponents(Collection):
             )
         )
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> DrawingComponent:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -122,12 +124,13 @@ class DrawingComponents(Collection):
                 |      Dim ThisDrawingComponent As DrawingComponent
                 |      Set ThisDrawingComponent = MyView.Components.Item(2)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: DrawingComponent
+        :rtype: DrawingComponent
         """
         return DrawingComponent(self.drawing_components.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -157,25 +160,11 @@ class DrawingComponents(Collection):
                 |      Set MyView  = MySheet.Views.ActiveView
                 |      MyView.Components.Remove(3)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
         return self.drawing_components.Remove(i_index)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(drawing_components)
-        # #     Dim iIndex (2)
-        # #     drawing_components.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
         return f'DrawingComponents()'
