@@ -11,6 +11,7 @@
 
 from pycatia.drafting_interfaces.drawing_dimension import DrawingDimension
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class DrawingDimensions(Collection):
@@ -34,7 +35,7 @@ class DrawingDimensions(Collection):
         super().__init__(com_object, child_object=DrawingDimension)
         self.drawing_dimensions = com_object
 
-    def add(self, i_type_dim, i_geom_elem, i_pt_coord_elem, i_line_rep):
+    def add(self, i_type_dim: int, i_geom_elem: tuple, i_pt_coord_elem: tuple, i_line_rep: int) -> DrawingDimension:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -97,21 +98,27 @@ class DrawingDimensions(Collection):
                 |      Dim MyDimension2 As DrawingDimension
                 |      Set MyDimension2 = MyView.Dimensions.Add(iType, myElements2(1), selpoints(3),catDimOffset)
 
-        :param CatDimType i_type_dim:
+        :param int i_type_dim:
         :param tuple i_geom_elem:
         :param tuple i_pt_coord_elem:
-        :param enum i_line_rep:
+        :param int i_line_rep:
         :return: DrawingDimension
+        :rtype: DrawingDimension
         """
         return DrawingDimension(
             self.drawing_dimensions.Add(
-                i_type_dim.com_object,
+                i_type_dim,
                 i_geom_elem,
                 i_pt_coord_elem,
                 i_line_rep)
         )
 
-    def add2(self, i_type_dim, i_geom_elem, i_pt_coord_elem, i_ldc_ref_elem, i_ldc_ref_angle):
+    def add2(self,
+             i_type_dim: int,
+             i_geom_elem: tuple,
+             i_pt_coord_elem: tuple,
+             i_ldc_ref_elem: cat_variant,
+             i_ldc_ref_angle: int) -> DrawingDimension:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -172,23 +179,24 @@ class DrawingDimensions(Collection):
                 |      Dim MyDimension As DrawingDimension
                 |      Set MyDimension = MyView.Dimensions.Add2(iType, myElements(1), selpoints(3), Line1, 0)
 
-        :param CatDimType i_type_dim:
+        :param int i_type_dim:
         :param tuple i_geom_elem:
         :param tuple i_pt_coord_elem:
         :param CATVariant i_ldc_ref_elem:
         :param int i_ldc_ref_angle:
         :return: DrawingDimension
+        :rtype: DrawingDimension
         """
         return DrawingDimension(
             self.drawing_dimensions.Add2(
-                i_type_dim.com_object,
+                i_type_dim,
                 i_geom_elem,
                 i_pt_coord_elem,
                 i_ldc_ref_elem,
                 i_ldc_ref_angle)
         )
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> DrawingDimension:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -228,12 +236,13 @@ class DrawingDimensions(Collection):
                 |          Dim ThatDrawingDimension As DrawingDimension
                 |          Set ThatDrawingDimension = MyView.Dimensions.Item("MyDimension")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: DrawingDimension
+        :rtype: DrawingDimension
         """
         return DrawingDimension(self.drawing_dimensions.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -260,25 +269,11 @@ class DrawingDimensions(Collection):
                 |          Set MyView  = MySheet.Views.ActiveView
                 |          MyView.Dimensions.Remove(3)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
         return self.drawing_dimensions.Remove(i_index)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(drawing_dimensions)
-        # #     Dim iIndex (2)
-        # #     drawing_dimensions.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
         return f'DrawingDimensions(name="{self.name}")'
