@@ -9,6 +9,7 @@
         
 """
 
+from pycatia.types import cat_variant
 from pycatia.drafting_interfaces.drawing_view import DrawingView
 from pycatia.system_interfaces.collection import Collection
 
@@ -38,7 +39,7 @@ class DrawingViews(Collection):
         self.drawing_views = com_object
 
     @property
-    def active_view(self):
+    def active_view(self) -> DrawingView:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -60,11 +61,12 @@ class DrawingViews(Collection):
                 |          Set ViewToWorkIn = MyDrawingDoc.Sheets.ActiveSheet.DrawingViews.ActiveView
 
         :return: DrawingView
+        :rtype: DrawingView
         """
 
         return DrawingView(self.drawing_views.ActiveView)
 
-    def add(self, i_drawing_view_name):
+    def add(self, i_drawing_view_name: str) -> DrawingView:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -98,10 +100,11 @@ class DrawingViews(Collection):
 
         :param str i_drawing_view_name:
         :return: DrawingView
+        :rtype: DrawingView
         """
         return DrawingView(self.drawing_views.Add(i_drawing_view_name))
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> DrawingView:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -144,12 +147,13 @@ class DrawingViews(Collection):
                 |          Dim ThatDrawingView As DrawingView
                 |          Set ThatDrawingView = MySheet.Views.ActiveView.Item("MyView")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: DrawingView
+        :rtype: DrawingView
         """
         return DrawingView(self.drawing_views.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -183,25 +187,11 @@ class DrawingViews(Collection):
                 |      MySheet.ActiveViews.Remove(3)
                 |      MySheet.ActiveViews.Remove("TopView")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
         return self.drawing_views.Remove(i_index)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(drawing_views)
-        # #     Dim iIndex (2)
-        # #     drawing_views.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
         return f'DrawingViews(name="{self.name}")'
