@@ -36,7 +36,7 @@ class PrintArea(AnyObject):
         self.print_area = com_object
 
     @property
-    def activation_state(self):
+    def activation_state(self) -> False:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -59,12 +59,13 @@ class PrintArea(AnyObject):
                 |             No activation or deactivation possible.
 
         :return: False
+        :rtype: False
         """
 
         return None
 
     @activation_state.setter
-    def activation_state(self, value):
+    def activation_state(self, value: False):
         """
         :param False value:
         """
@@ -72,7 +73,7 @@ class PrintArea(AnyObject):
         self.print_area.ActivationState = value
 
     @property
-    def area_height(self):
+    def area_height(self) -> False:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -93,12 +94,13 @@ class PrintArea(AnyObject):
                 |         E_FAIL
 
         :return: False
+        :rtype: False
         """
 
         return None
 
     @area_height.setter
-    def area_height(self, value):
+    def area_height(self, value: False):
         """
         :param False value:
         """
@@ -106,7 +108,7 @@ class PrintArea(AnyObject):
         self.print_area.AreaHeigth = value
 
     @property
-    def area_low_x(self):
+    def area_low_x(self) -> False:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -126,12 +128,13 @@ class PrintArea(AnyObject):
                 |         E_FAIL
 
         :return: False
+        :rtype: False
         """
 
         return None
 
     @area_low_x.setter
-    def area_low_x(self, value):
+    def area_low_x(self, value: False):
         """
         :param False value:
         """
@@ -139,7 +142,7 @@ class PrintArea(AnyObject):
         self.print_area.AreaLowX = value
 
     @property
-    def area_low_y(self):
+    def area_low_y(self) -> False:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -159,12 +162,13 @@ class PrintArea(AnyObject):
                 |         E_FAIL
 
         :return: False
+        :rtype: False
         """
 
         return None
 
     @area_low_y.setter
-    def area_low_y(self, value):
+    def area_low_y(self, value: False):
         """
         :param False value:
         """
@@ -172,7 +176,7 @@ class PrintArea(AnyObject):
         self.print_area.AreaLowY = value
 
     @property
-    def area_width(self):
+    def area_width(self) -> False:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -193,19 +197,20 @@ class PrintArea(AnyObject):
                 |         E_FAIL
 
         :return: False
+        :rtype: False
         """
 
         return None
 
     @area_width.setter
-    def area_width(self, value):
+    def area_width(self, value: False):
         """
         :param False value:
         """
 
         self.print_area.AreaWidth = value
 
-    def get_area(self, o_x, o_y, o_width, o_height, o_activated):
+    def get_area(self, o_x: float, o_y: float, o_width: float, o_height: float, o_activated: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -247,6 +252,7 @@ class PrintArea(AnyObject):
         :param float o_height:
         :param bool o_activated:
         :return: None
+        :rtype: None
         """
         return self.print_area.GetArea(o_x, o_y, o_width, o_height, o_activated)
         # # # # Autogenerated comment: 
@@ -265,7 +271,7 @@ class PrintArea(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_area(self, i_x, i_y, i_width, i_height):
+    def set_area(self, i_x: float, i_y: float, i_width: float, i_height: float) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -304,6 +310,7 @@ class PrintArea(AnyObject):
         :param float i_width:
         :param float i_height:
         :return: None
+        :rtype: None
         """
         return self.print_area.SetArea(i_x, i_y, i_width, i_height)
 
