@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -17,7 +17,7 @@ class HybridShapeAssemble(HybridShape):
 
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -47,10 +47,10 @@ class HybridShapeAssemble(HybridShape):
         self.hybrid_shape_assemble = com_object
 
     @property
-    def invert(self):
+    def invert(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Invert() As boolean
                 | 
                 |     Returns or sets the invert mode.
@@ -67,22 +67,23 @@ class HybridShapeAssemble(HybridShape):
                 |          HybShpAssemble.Invert = True
 
         :return: bool
+        :rtype: bool
         """
 
         return self.hybrid_shape_assemble.Invert
 
     @invert.setter
-    def invert(self, value):
+    def invert(self, value: bool):
         """
         :param bool value:
         """
 
         self.hybrid_shape_assemble.Invert = value
 
-    def add_element(self, i_element):
+    def add_element(self, i_element: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddElement(Reference iElement)
                 | 
                 |     Adds an element to the hybrid shape assemble feature
@@ -106,6 +107,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param Reference i_element:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.AddElement(i_element.com_object)
         # # # # Autogenerated comment: 
@@ -124,10 +126,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_sub_element(self, i_sub_element):
+    def add_sub_element(self, i_sub_element: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddSubElement(Reference iSubElement)
                 | 
                 |     Adds a sub element to the hybrid shape assemble feature
@@ -141,6 +143,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param Reference i_sub_element:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.AddSubElement(i_sub_element.com_object)
         # # # # Autogenerated comment: 
@@ -159,10 +162,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def append_federated_element(self, i_element):
+    def append_federated_element(self, i_element: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AppendFederatedElement(Reference iElement)
                 | 
                 |     Appends an init to the list of elements to federate.
@@ -177,6 +180,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param Reference i_element:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.AppendFederatedElement(i_element.com_object)
         # # # # Autogenerated comment: 
@@ -195,10 +199,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_angular_tolerance(self):
+    def get_angular_tolerance(self) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngularTolerance() As double
                 | 
                 |     Get the angular tolerance.
@@ -209,13 +213,14 @@ class HybridShapeAssemble(HybridShape):
                 |             The angular tolerance.
 
         :return: float
+        :rtype: float
         """
         return self.hybrid_shape_assemble.GetAngularTolerance()
 
-    def get_angular_tolerance_mode(self):
+    def get_angular_tolerance_mode(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAngularToleranceMode() As boolean
                 | 
                 |     Get the angular tolerance mode.
@@ -226,13 +231,14 @@ class HybridShapeAssemble(HybridShape):
                 |             The angular tolerance mode.
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_assemble.GetAngularToleranceMode()
 
-    def get_connex(self):
+    def get_connex(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetConnex() As boolean
                 | 
                 |     Get the connex checker flag.
@@ -242,13 +248,14 @@ class HybridShapeAssemble(HybridShape):
                 |         oConnex
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_assemble.GetConnex()
 
-    def get_deviation(self):
+    def get_deviation(self) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDeviation() As double
                 | 
                 |     Get the deviation value.
@@ -259,13 +266,14 @@ class HybridShapeAssemble(HybridShape):
                 |             The deviation.
 
         :return: float
+        :rtype: float
         """
         return self.hybrid_shape_assemble.GetDeviation()
 
-    def get_element(self, i_rank):
+    def get_element(self, i_rank: int) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetElement(long iRank) As Reference
                 | 
                 |     Retrieves an element used by the hybrid shape assemble feature
@@ -285,13 +293,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_rank:
         :return: Reference
+        :rtype: Reference
         """
         return Reference(self.hybrid_shape_assemble.GetElement(i_rank))
 
-    def get_elements_size(self):
+    def get_elements_size(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetElementsSize() As long
                 | 
                 |     Returns the size of the list of elements to assemble in the hybrid shape
@@ -310,13 +319,14 @@ class HybridShapeAssemble(HybridShape):
                 |                  oSize = HybShpAssemble.GetElementsSize
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_assemble.GetElementsSize()
 
-    def get_federated_element(self, i_rank):
+    def get_federated_element(self, i_rank: int) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetFederatedElement(long iRank) As Reference
                 | 
                 |     Retrieves an federated inits used by the hybrid shape assemble feature
@@ -334,13 +344,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_rank:
         :return: Reference
+        :rtype: Reference
         """
         return Reference(self.hybrid_shape_assemble.GetFederatedElement(i_rank))
 
-    def get_federated_elements_size(self):
+    def get_federated_elements_size(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetFederatedElementsSize() As long
                 | 
                 |     Gets the number of federated inits.
@@ -351,13 +362,14 @@ class HybridShapeAssemble(HybridShape):
                 |             Number of elements.
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_assemble.GetFederatedElementsSize()
 
-    def get_federation_propagation(self):
+    def get_federation_propagation(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetFederationPropagation() As long
                 | 
                 |     Gets the propagation mode of the federation.
@@ -369,13 +381,14 @@ class HybridShapeAssemble(HybridShape):
                 |             3:Tangency).
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_assemble.GetFederationPropagation()
 
-    def get_manifold(self):
+    def get_manifold(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetManifold() As boolean
                 | 
                 |     Get the manifold checker flag.
@@ -385,13 +398,14 @@ class HybridShapeAssemble(HybridShape):
                 |         oManifold
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_assemble.GetManifold()
 
-    def get_simplify(self):
+    def get_simplify(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSimplify() As boolean
                 | 
                 |     Get the simplify flag.
@@ -401,13 +415,14 @@ class HybridShapeAssemble(HybridShape):
                 |         oSimplify
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_assemble.GetSimplify()
 
-    def get_sub_element(self, i_rank):
+    def get_sub_element(self, i_rank: int) -> Reference:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSubElement(long iRank) As Reference
                 | 
                 |     Retrieves a sub element used by the hybrid shape assemble feature
@@ -420,13 +435,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_rank:
         :return: Reference
+        :rtype: Reference
         """
         return Reference(self.hybrid_shape_assemble.GetSubElement(i_rank))
 
-    def get_sub_elements_size(self):
+    def get_sub_elements_size(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSubElementsSize() As long
                 | 
                 |     Returns the size of the list of sub-elements to remove in the hybrid shape
@@ -445,13 +461,14 @@ class HybridShapeAssemble(HybridShape):
                 |                  oSize = HybShpAssemble.GetSubElementsSize
 
         :return: int
+        :rtype: int
         """
         return self.hybrid_shape_assemble.GetSubElementsSize()
 
-    def get_suppress_mode(self):
+    def get_suppress_mode(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSuppressMode() As boolean
                 | 
                 |     Get the SuppressMode flag.
@@ -461,13 +478,14 @@ class HybridShapeAssemble(HybridShape):
                 |         oSuppressMode
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_assemble.GetSuppressMode()
 
-    def get_tangency_continuity(self):
+    def get_tangency_continuity(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetTangencyContinuity() As boolean
                 | 
                 |     Get the tangency continuity checker flag.
@@ -477,13 +495,14 @@ class HybridShapeAssemble(HybridShape):
                 |         oTangencyContinuity
 
         :return: bool
+        :rtype: bool
         """
         return self.hybrid_shape_assemble.GetTangencyContinuity()
 
-    def remove_element(self, i_rank):
+    def remove_element(self, i_rank: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveElement(long iRank)
                 | 
                 |     Removes an element used by the hybrid shape assemble feature
@@ -502,13 +521,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_rank:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.RemoveElement(i_rank)
 
-    def remove_federated_element(self, i_rank):
+    def remove_federated_element(self, i_rank: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveFederatedElement(long iRank)
                 | 
                 |     Removes an element to the list of elements to federate.
@@ -520,13 +540,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_rank:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.RemoveFederatedElement(i_rank)
 
-    def remove_sub_element(self, i_rank):
+    def remove_sub_element(self, i_rank: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveSubElement(long iRank)
                 | 
                 |     Removes a sub element used by the hybrid shape assemble feature
@@ -539,13 +560,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_rank:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.RemoveSubElement(i_rank)
 
-    def replace_element(self, i_pos, i_element):
+    def replace_element(self, i_pos: int, i_element: Reference) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub ReplaceElement(long iPos,
                 | Reference iElement)
                 | 
@@ -568,6 +590,7 @@ class HybridShapeAssemble(HybridShape):
         :param int i_pos:
         :param Reference i_element:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.ReplaceElement(i_pos, i_element.com_object)
         # # # # Autogenerated comment: 
@@ -586,10 +609,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_angular_tolerance(self, i_value):
+    def set_angular_tolerance(self, i_value: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngularTolerance(double iValue)
                 | 
                 |     Set the angular tolerance.
@@ -601,13 +624,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param float i_value:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetAngularTolerance(i_value)
 
-    def set_angular_tolerance_mode(self, i_value):
+    def set_angular_tolerance_mode(self, i_value: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAngularToleranceMode(boolean iValue)
                 | 
                 |     Set the angular tolerance mode.
@@ -619,6 +643,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param bool i_value:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetAngularToleranceMode(i_value)
         # # # # Autogenerated comment: 
@@ -637,10 +662,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_connex(self, i_connex):
+    def set_connex(self, i_connex: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetConnex(boolean iConnex)
                 | 
                 |     Set the connex checker flag.
@@ -651,6 +676,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param bool i_connex:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetConnex(i_connex)
         # # # # Autogenerated comment: 
@@ -669,10 +695,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_deviation(self, ideviation):
+    def set_deviation(self, ideviation: float) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDeviation(double ideviation)
                 | 
                 |     Set the deviation value.
@@ -684,13 +710,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param float ideviation:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetDeviation(ideviation)
 
-    def set_federation_propagation(self, i_mode):
+    def set_federation_propagation(self, i_mode: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetFederationPropagation(long iMode)
                 | 
                 |     Sets the propagation mode of federation.
@@ -703,13 +730,14 @@ class HybridShapeAssemble(HybridShape):
 
         :param int i_mode:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetFederationPropagation(i_mode)
 
-    def set_manifold(self, i_manifold):
+    def set_manifold(self, i_manifold: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetManifold(boolean iManifold)
                 | 
                 |     Set the manifold checker flag.
@@ -720,6 +748,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param bool i_manifold:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetManifold(i_manifold)
         # # # # Autogenerated comment: 
@@ -738,10 +767,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_simplify(self, i_simplify):
+    def set_simplify(self, i_simplify: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSimplify(boolean iSimplify)
                 | 
                 |     Set the simplify flag.
@@ -752,6 +781,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param bool i_simplify:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetSimplify(i_simplify)
         # # # # Autogenerated comment: 
@@ -770,10 +800,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_suppress_mode(self, i_suppress_mode):
+    def set_suppress_mode(self, i_suppress_mode: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSuppressMode(boolean iSuppressMode)
                 | 
                 |     Set the SuppressMode flag.
@@ -784,6 +814,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param bool i_suppress_mode:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetSuppressMode(i_suppress_mode)
         # # # # Autogenerated comment: 
@@ -802,10 +833,10 @@ class HybridShapeAssemble(HybridShape):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_tangency_continuity(self, i_tangency_continuity):
+    def set_tangency_continuity(self, i_tangency_continuity: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetTangencyContinuity(boolean iTangencyContinuity)
                 | 
                 |     Set the tangency continuity checker flag.
@@ -816,6 +847,7 @@ class HybridShapeAssemble(HybridShape):
 
         :param bool i_tangency_continuity:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape_assemble.SetTangencyContinuity(i_tangency_continuity)
         # # # # Autogenerated comment: 
