@@ -11,10 +11,10 @@
 
 from pycatia.in_interfaces.camera import Camera
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class Cameras(Collection):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -56,10 +56,10 @@ class Cameras(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=Camera)
         self.cameras = com_object
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> Camera:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -90,15 +90,16 @@ class Cameras(Collection):
                 |          Dim ThatCamera As Camera
                 |          Set ThatCamera = CATIA.ActiveDocument.Cameras.Item("MyCamera")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: Camera
+        :rtype: Camera
         """
         return Camera(self.cameras.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub Remove(CATVariant iIndex)
                 | 
                 |     Removes a camera from the Cameras collection.
@@ -123,25 +124,11 @@ class Cameras(Collection):
                 |      CATIA.ActiveDocument.Cameras.Remove(10)
                 |      CATIA.ActiveDocument.Cameras.Remove("CameraToBeRemoved")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
         return self.cameras.Remove(i_index)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(cameras)
-        # #     Dim iIndex (2)
-        # #     cameras.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'Cameras(name="{ self.name }")'
+        return f'Cameras(name="{self.name}")'
