@@ -41,7 +41,7 @@ class FileSystem(AnyObject):
         self.file_system = com_object
 
     @property
-    def file_separator(self):
+    def file_separator(self) -> str:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -56,15 +56,16 @@ class FileSystem(AnyObject):
                 |             The file separator string.
 
         :return: str
+        :rtype: str
         """
 
         return self.file_system.FileSeparator
 
     @property
-    def path_separator(self):
+    def path_separator(self) -> str:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property PathSeparator() As CATBSTR (Read Only)
                 | 
                 |     Returns the path separator string. (usually,; on Windows and : on UNIX)
@@ -75,12 +76,13 @@ class FileSystem(AnyObject):
                 |             The path separator string.
 
         :return: str
+        :rtype: str
         """
 
         return self.file_system.PathSeparator
 
     @property
-    def temporary_directory(self):
+    def temporary_directory(self) -> Folder:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -96,11 +98,12 @@ class FileSystem(AnyObject):
                 |             directory.
 
         :return: Folder
+        :rtype: Folder
         """
 
         return Folder(self.file_system.TemporaryDirectory)
 
-    def concatenate_paths(self, i_path_chunk1, i_path_chunk2):
+    def concatenate_paths(self, i_path_chunk1: str, i_path_chunk2: str) -> str:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -126,10 +129,11 @@ class FileSystem(AnyObject):
         :param str i_path_chunk1:
         :param str i_path_chunk2:
         :return: str
+        :rtype: str
         """
         return self.file_system.ConcatenatePaths(i_path_chunk1, i_path_chunk2)
 
-    def copy_file(self, i_path_source, i_path_destination, i_overwrite):
+    def copy_file(self, i_path_source: str, i_path_destination: str, i_overwrite: bool) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -163,6 +167,7 @@ class FileSystem(AnyObject):
         :param str i_path_destination:
         :param bool i_overwrite:
         :return: None
+        :rtype: None
         """
         return self.file_system.CopyFile(i_path_source, i_path_destination, i_overwrite)
         # # # # Autogenerated comment: 
@@ -181,7 +186,7 @@ class FileSystem(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def copy_folder(self, i_source_path, i_destination_path):
+    def copy_folder(self, i_source_path: str, i_destination_path: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -211,13 +216,14 @@ class FileSystem(AnyObject):
         :param str i_source_path:
         :param str i_destination_path:
         :return: None
+        :rtype: None
         """
         return self.file_system.CopyFolder(i_source_path, i_destination_path)
 
-    def create_file(self, i_path, i_overwrite):
+    def create_file(self, i_path: str, i_overwrite: bool) -> File:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func CreateFile(CATBSTR iPath,
                 | boolean iOverwrite) As File
                 | 
@@ -246,10 +252,11 @@ class FileSystem(AnyObject):
         :param str i_path:
         :param bool i_overwrite:
         :return: File
+        :rtype: File
         """
         return File(self.file_system.CreateFile(i_path, i_overwrite))
 
-    def create_folder(self, i_path):
+    def create_folder(self, i_path: str) -> Folder:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -275,10 +282,11 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: Folder
+        :rtype: Folder
         """
         return Folder(self.file_system.CreateFolder(i_path))
 
-    def delete_file(self, i_path):
+    def delete_file(self, i_path: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -300,10 +308,11 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: None
+        :rtype: None
         """
         return self.file_system.DeleteFile(i_path)
 
-    def delete_folder(self, i_path):
+    def delete_folder(self, i_path: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -325,10 +334,11 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: None
+        :rtype: None
         """
         return self.file_system.DeleteFolder(i_path)
 
-    def file_exists(self, i_path):
+    def file_exists(self, i_path: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -352,10 +362,11 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: bool
+        :rtype: bool
         """
         return self.file_system.FileExists(i_path)
 
-    def folder_exists(self, i_path):
+    def folder_exists(self, i_path: str) -> bool:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -379,10 +390,11 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: bool
+        :rtype: bool
         """
         return self.file_system.FolderExists(i_path)
 
-    def get_file(self, i_path):
+    def get_file(self, i_path: str) -> File:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -405,10 +417,11 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: File
+        :rtype: File
         """
         return File(self.file_system.GetFile(i_path))
 
-    def get_folder(self, i_path):
+    def get_folder(self, i_path: str) -> Folder:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -434,6 +447,7 @@ class FileSystem(AnyObject):
 
         :param str i_path:
         :return: Folder
+        :rtype: Folder
         """
         return Folder(self.file_system.GetFolder(i_path))
 
