@@ -13,7 +13,6 @@ from pycatia.system_interfaces.setting_controller import SettingController
 
 
 class PrintersSettingAtt(SettingController):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -36,10 +35,10 @@ class PrintersSettingAtt(SettingController):
         super().__init__(com_object)
         self.printers_setting_att = com_object
 
-    def add_printer_directory(self, i_printer_dir, i_printer_dir_state):
+    def add_printer_directory(self, i_printer_dir: str, i_printer_dir_state: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddPrinterDirectory(CATBSTR iPrinterDir,
                 | CatPrinterDirState iPrinterDirState)
                 | 
@@ -68,30 +67,16 @@ class PrintersSettingAtt(SettingController):
                 |             CatPrinterDirFree : the printers included in the directory are free.
 
         :param str i_printer_dir:
-        :param CatPrinterDirState i_printer_dir_state:
+        :param int i_printer_dir_state:
         :return: None
+        :rtype: None
         """
-        return self.printers_setting_att.AddPrinterDirectory(i_printer_dir, i_printer_dir_state.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'add_printer_directory'
-        # # vba_code = """
-        # # Public Function add_printer_directory(printers_setting_att)
-        # #     Dim iPrinterDir (2)
-        # #     printers_setting_att.AddPrinterDirectory iPrinterDir
-        # #     add_printer_directory = iPrinterDir
-        # # End Function
-        # # """
+        return self.printers_setting_att.AddPrinterDirectory(i_printer_dir, i_printer_dir_state)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def add_printer_group(self, i_printer_group_name, i_printer_names):
+    def add_printer_group(self, i_printer_group_name: str, i_printer_names: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddPrinterGroup(CATBSTR iPrinterGroupName,
                 | CATSafeArrayVariant iPrinterNames)
                 | 
@@ -108,6 +93,7 @@ class PrintersSettingAtt(SettingController):
         :param str i_printer_group_name:
         :param tuple i_printer_names:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.AddPrinterGroup(i_printer_group_name, i_printer_names)
         # # # # Autogenerated comment: 
@@ -126,10 +112,10 @@ class PrintersSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_driver_configuration_path(self, o_driver_cfg_path):
+    def get_driver_configuration_path(self, o_driver_cfg_path: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetDriverConfigurationPath(CATBSTR oDriverCfgPath)
                 | 
                 |     Returns the driver configuration file.
@@ -141,13 +127,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str o_driver_cfg_path:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.GetDriverConfigurationPath(o_driver_cfg_path)
 
-    def get_driver_configuration_path_info(self, o_admin_level, o_locked):
+    def get_driver_configuration_path_info(self, o_admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDriverConfigurationPathInfo(CATBSTR oAdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -174,13 +161,14 @@ class PrintersSettingAtt(SettingController):
         :param str o_admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.printers_setting_att.GetDriverConfigurationPathInfo(o_admin_level, o_locked)
 
-    def get_new_printer_directory(self, o_new_printer_dir):
+    def get_new_printer_directory(self, o_new_printer_dir: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetNewPrinterDirectory(CATBSTR oNewPrinterDir)
                 | 
                 |     Returns the directory where new printers will be added.
@@ -194,13 +182,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str o_new_printer_dir:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.GetNewPrinterDirectory(o_new_printer_dir)
 
-    def get_new_printer_directory_info(self, o_admin_level, o_locked):
+    def get_new_printer_directory_info(self, o_admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetNewPrinterDirectoryInfo(CATBSTR oAdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -227,13 +216,14 @@ class PrintersSettingAtt(SettingController):
         :param str o_admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.printers_setting_att.GetNewPrinterDirectoryInfo(o_admin_level, o_locked)
 
-    def get_printer_array_for_group(self, i_printer_group_name):
+    def get_printer_array_for_group(self, i_printer_group_name: str) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPrinterArrayForGroup(CATBSTR iPrinterGroupName) As
                 | CATSafeArrayVariant
                 | 
@@ -249,13 +239,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str i_printer_group_name:
         :return: tuple
+        :rtype: tuple
         """
         return self.printers_setting_att.GetPrinterArrayForGroup(i_printer_group_name)
 
-    def get_printer_directories(self):
+    def get_printer_directories(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPrinterDirectories() As CATSafeArrayVariant
                 | 
                 |     Returns the directories of printer files.
@@ -264,13 +255,14 @@ class PrintersSettingAtt(SettingController):
                 |         array of directories where 3DPLM printers are defined.
 
         :return: tuple
+        :rtype: tuple
         """
         return self.printers_setting_att.GetPrinterDirectories()
 
-    def get_printer_directories_info(self, o_admin_level, o_locked):
+    def get_printer_directories_info(self, o_admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPrinterDirectoriesInfo(CATBSTR oAdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -297,13 +289,14 @@ class PrintersSettingAtt(SettingController):
         :param str o_admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.printers_setting_att.GetPrinterDirectoriesInfo(o_admin_level, o_locked)
 
-    def get_printer_directory_state(self, i_printer_dir):
+    def get_printer_directory_state(self, i_printer_dir: str) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPrinterDirectoryState(CATBSTR iPrinterDir) As
                 | CatPrinterDirState
                 | 
@@ -329,14 +322,15 @@ class PrintersSettingAtt(SettingController):
                 |         CatPrinterDirFree : the printers included in the directory are free.
 
         :param str i_printer_dir:
-        :return: enum cat_printer_dir_state
+        :return: int
+        :rtype: int
         """
         return self.printers_setting_att.GetPrinterDirectoryState(i_printer_dir)
 
-    def get_printer_groups(self):
+    def get_printer_groups(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPrinterGroups() As CATSafeArrayVariant
                 | 
                 |     Returns the printer groups.
@@ -345,13 +339,14 @@ class PrintersSettingAtt(SettingController):
                 |         array of printer group names
 
         :return: tuple
+        :rtype: tuple
         """
         return self.printers_setting_att.GetPrinterGroups()
 
-    def get_printer_groups_info(self, o_admin_level, o_locked):
+    def get_printer_groups_info(self, o_admin_level: str, o_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPrinterGroupsInfo(CATBSTR oAdminLevel,
                 | CATBSTR oLocked) As boolean
                 | 
@@ -378,13 +373,14 @@ class PrintersSettingAtt(SettingController):
         :param str o_admin_level:
         :param str o_locked:
         :return: bool
+        :rtype: bool
         """
         return self.printers_setting_att.GetPrinterGroupsInfo(o_admin_level, o_locked)
 
-    def modify_printer_array_for_group(self, i_printer_group_name, i_printer_names):
+    def modify_printer_array_for_group(self, i_printer_group_name: str, i_printer_names: tuple) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub ModifyPrinterArrayForGroup(CATBSTR iPrinterGroupName,
                 | CATSafeArrayVariant iPrinterNames)
                 | 
@@ -401,6 +397,7 @@ class PrintersSettingAtt(SettingController):
         :param str i_printer_group_name:
         :param tuple i_printer_names:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.ModifyPrinterArrayForGroup(i_printer_group_name, i_printer_names)
         # # # # Autogenerated comment: 
@@ -419,10 +416,10 @@ class PrintersSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def modify_printer_directory_state(self, i_printer_dir, i_printer_dir_state):
+    def modify_printer_directory_state(self, i_printer_dir: str, i_printer_dir_state: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub ModifyPrinterDirectoryState(CATBSTR iPrinterDir,
                 | CatPrinterDirState iPrinterDirState)
                 | 
@@ -448,54 +445,42 @@ class PrintersSettingAtt(SettingController):
                 |             CatPrinterDirFree : the printers included in the directory are free.
 
         :param str i_printer_dir:
-        :param CatPrinterDirState i_printer_dir_state:
+        :param int i_printer_dir_state:
         :return: None
+        :rtype: None
         """
-        return self.printers_setting_att.ModifyPrinterDirectoryState(i_printer_dir, i_printer_dir_state.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'modify_printer_directory_state'
-        # # vba_code = """
-        # # Public Function modify_printer_directory_state(printers_setting_att)
-        # #     Dim iPrinterDir (2)
-        # #     printers_setting_att.ModifyPrinterDirectoryState iPrinterDir
-        # #     modify_printer_directory_state = iPrinterDir
-        # # End Function
-        # # """
+        return self.printers_setting_att.ModifyPrinterDirectoryState(i_printer_dir, i_printer_dir_state)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def remove_all_printer_directories(self):
+    def remove_all_printer_directories(self) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveAllPrinterDirectories()
                 | 
                 |     Remove all the directories including printer files.
 
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.RemoveAllPrinterDirectories()
 
-    def remove_all_printer_groups(self):
+    def remove_all_printer_groups(self) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveAllPrinterGroups()
                 | 
                 |     Remove all the groups of printers.
 
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.RemoveAllPrinterGroups()
 
-    def remove_printer_directory(self, i_printer_dir):
+    def remove_printer_directory(self, i_printer_dir: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemovePrinterDirectory(CATBSTR iPrinterDir)
                 | 
                 |     Remove a directory of printer files from the directories
@@ -508,13 +493,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str i_printer_dir:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.RemovePrinterDirectory(i_printer_dir)
 
-    def remove_printer_group(self, i_printer_group_name):
+    def remove_printer_group(self, i_printer_group_name: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemovePrinterGroup(CATBSTR iPrinterGroupName)
                 | 
                 |     Remove a group of printers.
@@ -526,13 +512,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str i_printer_group_name:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.RemovePrinterGroup(i_printer_group_name)
 
-    def set_driver_configuration_path(self, i_driver_cfg_path):
+    def set_driver_configuration_path(self, i_driver_cfg_path: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDriverConfigurationPath(CATBSTR iDriverCfgPath)
                 | 
                 |     Sets the driver configuration file.
@@ -544,13 +531,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str i_driver_cfg_path:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.SetDriverConfigurationPath(i_driver_cfg_path)
 
-    def set_driver_configuration_path_lock(self, i_lock):
+    def set_driver_configuration_path_lock(self, i_lock: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDriverConfigurationPathLock(boolean iLock)
                 | 
                 |     Locks or unlocks the driver configuration file.
@@ -568,6 +556,7 @@ class PrintersSettingAtt(SettingController):
 
         :param bool i_lock:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.SetDriverConfigurationPathLock(i_lock)
         # # # # Autogenerated comment: 
@@ -586,10 +575,10 @@ class PrintersSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_new_printer_directory(self, i_new_printer_dir):
+    def set_new_printer_directory(self, i_new_printer_dir: str) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetNewPrinterDirectory(CATBSTR iNewPrinterDir)
                 | 
                 |     Sets the directory where new printers will be added.
@@ -603,13 +592,14 @@ class PrintersSettingAtt(SettingController):
 
         :param str i_new_printer_dir:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.SetNewPrinterDirectory(i_new_printer_dir)
 
-    def set_new_printer_directory_lock(self, i_lock):
+    def set_new_printer_directory_lock(self, i_lock: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetNewPrinterDirectoryLock(boolean iLock)
                 | 
                 |     Locks or unlocks the directory where printers will be
@@ -628,6 +618,7 @@ class PrintersSettingAtt(SettingController):
 
         :param bool i_lock:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.SetNewPrinterDirectoryLock(i_lock)
         # # # # Autogenerated comment: 
@@ -646,10 +637,10 @@ class PrintersSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_printer_directories_lock(self, i_lock):
+    def set_printer_directories_lock(self, i_lock: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetPrinterDirectoriesLock(boolean iLock)
                 | 
                 |     Locks or unlocks the directories of printer files and their
@@ -668,6 +659,7 @@ class PrintersSettingAtt(SettingController):
 
         :param bool i_lock:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.SetPrinterDirectoriesLock(i_lock)
         # # # # Autogenerated comment: 
@@ -686,10 +678,10 @@ class PrintersSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_printer_groups_lock(self, i_lock):
+    def set_printer_groups_lock(self, i_lock: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetPrinterGroupsLock(boolean iLock)
                 | 
                 |     Locks or unlocks the definition of each printer group.
@@ -707,6 +699,7 @@ class PrintersSettingAtt(SettingController):
 
         :param bool i_lock:
         :return: None
+        :rtype: None
         """
         return self.printers_setting_att.SetPrinterGroupsLock(i_lock)
         # # # # Autogenerated comment: 
@@ -726,4 +719,4 @@ class PrintersSettingAtt(SettingController):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'PrintersSettingAtt(name="{ self.name }")'
+        return f'PrintersSettingAtt(name="{self.name}")'
