@@ -36,21 +36,22 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att = com_object
 
     @property
-    def arc_selection_activation(self):
+    def arc_selection_activation(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ArcSelectionActivation() As boolean
                 | 
                 |     Retrieves or Sets the arc-selection mode applied to the specification tree.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.tree_viz_manip_setting_att.ArcSelectionActivation
 
     @arc_selection_activation.setter
-    def arc_selection_activation(self, value):
+    def arc_selection_activation(self, value: bool):
         """
         :param bool value:
         """
@@ -58,22 +59,23 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att.ArcSelectionActivation = value
 
     @property
-    def auto_expand_activation(self):
+    def auto_expand_activation(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property AutoExpandActivation() As boolean
                 | 
                 |     Retrieves or Sets the automatic expand mode applied to the specification
                 |     tree.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.tree_viz_manip_setting_att.AutoExpandActivation
 
     @auto_expand_activation.setter
-    def auto_expand_activation(self, value):
+    def auto_expand_activation(self, value: bool):
         """
         :param bool value:
         """
@@ -81,22 +83,23 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att.AutoExpandActivation = value
 
     @property
-    def auto_scroll_activation(self):
+    def auto_scroll_activation(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property AutoScrollActivation() As boolean
                 | 
                 |     Retrieves or Sets the automatic scrolling mode applied to the specification
                 |     tree.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.tree_viz_manip_setting_att.AutoScrollActivation
 
     @auto_scroll_activation.setter
-    def auto_scroll_activation(self, value):
+    def auto_scroll_activation(self, value: bool):
         """
         :param bool value:
         """
@@ -104,21 +107,22 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att.AutoScrollActivation = value
 
     @property
-    def display_geom_on_scrolling(self):
+    def display_geom_on_scrolling(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property DisplayGeomOnScrolling() As boolean
                 | 
                 |     Retrieves or Sets the "display geometry on scrolling" mode.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.tree_viz_manip_setting_att.DisplayGeomOnScrolling
 
     @display_geom_on_scrolling.setter
-    def display_geom_on_scrolling(self, value):
+    def display_geom_on_scrolling(self, value: bool):
         """
         :param bool value:
         """
@@ -126,44 +130,46 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att.DisplayGeomOnScrolling = value
 
     @property
-    def orientation(self):
+    def orientation(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Orientation() As CatTreeOrientationEnum
                 | 
                 |     Retrieves or Sets the orientation applied to the specification tree.
 
-        :return: enum cat_tree_orientation_enum
+        :return: int
+        :rtype: int
         """
 
         return self.tree_viz_manip_setting_att.Orientation
 
     @orientation.setter
-    def orientation(self, value):
+    def orientation(self, value: int):
         """
-        :param enum cat_tree_orientation_enum value:
+        :param int value:
         """
 
         self.tree_viz_manip_setting_att.Orientation = value
 
     @property
-    def show_activation(self):
+    def show_activation(self) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ShowActivation() As boolean
                 | 
                 |     Retrieves or Sets the visualization Show/NoShow's mode applied to the
                 |     specification tree.
 
         :return: bool
+        :rtype: bool
         """
 
         return self.tree_viz_manip_setting_att.ShowActivation
 
     @show_activation.setter
-    def show_activation(self, value):
+    def show_activation(self, value: bool):
         """
         :param bool value:
         """
@@ -171,22 +177,23 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att.ShowActivation = value
 
     @property
-    def size(self):
+    def size(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Size() As long
                 | 
                 |     Retrieves or Sets the number of characters shown for the text of the
                 |     specification tree.
 
         :return: int
+        :rtype: int
         """
 
         return self.tree_viz_manip_setting_att.Size
 
     @size.setter
-    def size(self, value):
+    def size(self, value: int):
         """
         :param int value:
         """
@@ -194,54 +201,56 @@ class TreeVizManipSettingAtt(SettingController):
         self.tree_viz_manip_setting_att.Size = value
 
     @property
-    def size_type(self):
+    def size_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property SizeType() As CatTreeSizeTypeEnum
                 | 
                 |     Retrieves or Sets the type of size applied to the text of the specification
                 |     tree.
 
-        :return: enum cat_tree_size_type_enum
+        :return: int
+        :rtype: int
         """
 
         return self.tree_viz_manip_setting_att.SizeType
 
     @size_type.setter
-    def size_type(self, value):
+    def size_type(self, value: int):
         """
-        :param enum cat_tree_size_type_enum value:
+        :param int value:
         """
 
         self.tree_viz_manip_setting_att.SizeType = value
 
     @property
-    def type(self):
+    def type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Type() As CatTreeTypeEnum
                 | 
                 |     Retrieves or Sets the type applied to the specification tree.
 
-        :return: enum cat_tree_type_enum
+        :return: int
+        :rtype: int
         """
 
         return self.tree_viz_manip_setting_att.Type
 
     @type.setter
-    def type(self, value):
+    def type(self, value: int):
         """
-        :param enum cat_tree_type_enum value:
+        :param int value:
         """
 
         self.tree_viz_manip_setting_att.Type = value
 
-    def get_arc_selection_activation_info(self, io_admin_level, io_locked):
+    def get_arc_selection_activation_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetArcSelectionActivationInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -269,13 +278,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetArcSelectionActivationInfo(io_admin_level, io_locked)
 
-    def get_auto_expand_activation_info(self, io_admin_level, io_locked):
+    def get_auto_expand_activation_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAutoExpandActivationInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -303,13 +313,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetAutoExpandActivationInfo(io_admin_level, io_locked)
 
-    def get_auto_scroll_activation_info(self, io_admin_level, io_locked):
+    def get_auto_scroll_activation_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetAutoScrollActivationInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -337,13 +348,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetAutoScrollActivationInfo(io_admin_level, io_locked)
 
-    def get_display_geom_on_scrolling_info(self, io_admin_level, io_locked):
+    def get_display_geom_on_scrolling_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetDisplayGeomOnScrollingInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -371,13 +383,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetDisplayGeomOnScrollingInfo(io_admin_level, io_locked)
 
-    def get_orientation_info(self, io_admin_level, io_locked):
+    def get_orientation_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetOrientationInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -405,13 +418,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetOrientationInfo(io_admin_level, io_locked)
 
-    def get_show_activation_info(self, io_admin_level, io_locked):
+    def get_show_activation_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetShowActivationInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -439,13 +453,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetShowActivationInfo(io_admin_level, io_locked)
 
-    def get_size_type_info(self, io_admin_level, io_locked):
+    def get_size_type_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSizeTypeInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -475,13 +490,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetSizeTypeInfo(io_admin_level, io_locked)
 
-    def get_type_info(self, io_admin_level, io_locked):
+    def get_type_info(self, io_admin_level: str, io_locked: str) -> bool:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetTypeInfo(CATBSTR ioAdminLevel,
                 | CATBSTR ioLocked) As boolean
                 | 
@@ -509,13 +525,14 @@ class TreeVizManipSettingAtt(SettingController):
         :param str io_admin_level:
         :param str io_locked:
         :return: bool
+        :rtype: bool
         """
         return self.tree_viz_manip_setting_att.GetTypeInfo(io_admin_level, io_locked)
 
-    def set_arc_selection_activation_lock(self, i_locked):
+    def set_arc_selection_activation_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetArcSelectionActivationLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the arc-selection mode applied to the specification
@@ -534,6 +551,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetArcSelectionActivationLock(i_locked)
         # # # # Autogenerated comment: 
@@ -552,10 +570,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_auto_expand_activation_lock(self, i_locked):
+    def set_auto_expand_activation_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAutoExpandActivationLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the automatic expand mode applied to the specification
@@ -574,6 +592,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetAutoExpandActivationLock(i_locked)
         # # # # Autogenerated comment: 
@@ -592,10 +611,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_auto_scroll_activation_lock(self, i_locked):
+    def set_auto_scroll_activation_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetAutoScrollActivationLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the automatic scrolling mode applied to the specification
@@ -614,6 +633,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetAutoScrollActivationLock(i_locked)
         # # # # Autogenerated comment: 
@@ -632,10 +652,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_display_geom_on_scrolling_lock(self, i_locked):
+    def set_display_geom_on_scrolling_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetDisplayGeomOnScrollingLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the "display geometry on scrolling" mode.
@@ -653,6 +673,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetDisplayGeomOnScrollingLock(i_locked)
         # # # # Autogenerated comment: 
@@ -671,10 +692,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_orientation_lock(self, i_locked):
+    def set_orientation_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetOrientationLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the orientation applied to the specification
@@ -693,6 +714,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetOrientationLock(i_locked)
         # # # # Autogenerated comment: 
@@ -711,10 +733,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_show_activation_lock(self, i_locked):
+    def set_show_activation_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetShowActivationLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the visualization Show/NoShow's mode applied to the
@@ -733,6 +755,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetShowActivationLock(i_locked)
         # # # # Autogenerated comment: 
@@ -751,10 +774,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_size_type_lock(self, i_locked):
+    def set_size_type_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSizeTypeLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the type of size applied to the text of the specification
@@ -775,6 +798,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetSizeTypeLock(i_locked)
         # # # # Autogenerated comment: 
@@ -793,10 +817,10 @@ class TreeVizManipSettingAtt(SettingController):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_type_lock(self, i_locked):
+    def set_type_lock(self, i_locked: bool) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetTypeLock(boolean iLocked)
                 | 
                 |     Locks or unlocks the type of the specification tree.
@@ -814,6 +838,7 @@ class TreeVizManipSettingAtt(SettingController):
 
         :param bool i_locked:
         :return: None
+        :rtype: None
         """
         return self.tree_viz_manip_setting_att.SetTypeLock(i_locked)
         # # # # Autogenerated comment: 
