@@ -118,10 +118,10 @@ class VisPropertySet(AnyObject):
         super().__init__(com_object)
         self.vis_property_set = com_object
 
-    def get_layer(self, o_layer_type, o_layer_value):
+    def get_layer(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetLayer(CatVisLayerType oLayerType,
                 | long oLayerValue) As CatVisPropertyStatus
                 | 
@@ -141,13 +141,12 @@ class VisPropertySet(AnyObject):
                 |             A value between 0 to 1000
                 |             This parameter is usefull only when the type of the layer is
                 |             catVisLayerBasic. 
-                | 
+                |
                 |     Example:
                 | 
                 |           The following sample shows how to retrieve layer of current
                 |           selection.
                 |          
-                | 
                 |          Dim layer
                 |          layer = CLng(0) 
                 |          Dim layertype As CatVisLayerType
@@ -160,16 +159,15 @@ class VisPropertySet(AnyObject):
                 |          MsgBox "layer =" & layer
                 |          End If
 
-        :param CatVisLayerType o_layer_type:
-        :param int o_layer_value:
-        :return: enum cat_vis_property_status
+        :return: tuple
+        :rtype: tuple
         """
-        return self.vis_property_set.GetLayer(o_layer_type.com_object, o_layer_value)
+        return self.vis_property_set.GetLayer()
 
-    def get_pick(self, o_pick):
+    def get_pick(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetPick(CatVisPropertyPick oPick) As
                 | CatVisPropertyStatus
                 | 
@@ -187,15 +185,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetPick pickstate
                 |          MsgBox "pick = " & pickstate
 
-        :param CatVisPropertyPick o_pick:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetPick(o_pick.com_object)
+        return self.vis_property_set.GetPick()
 
-    def get_real_color(self, o_red, o_green, o_blue):
+    def get_real_color(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetRealColor(long oRed,
                 | long oGreen,
                 | long oBlue) As CatVisPropertyStatus
@@ -219,14 +217,11 @@ class VisPropertySet(AnyObject):
                 |             catVisPropertyUnDefined
                 |                 The real color is not the same for all elements of the current
                 |                 selection, so oRed, oGreen and oBlue are not valid
-                |                 
-                | 
+                |
                 |     Example:
-                | 
                 |           The following sample shows how to retrieve real colors of current
                 |           selection.
-                |          
-                | 
+                |
                 |          Dim r, g, b 
                 |          r = CLng(0) 
                 |          g = CLng(0) 
@@ -235,17 +230,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetRealColor r, g, b 
                 |          MsgBox "r = " & r & " g = " & g & " b = " & b
 
-        :param int o_red:
-        :param int o_green:
-        :param int o_blue:
-        :return: enum cat_vis_property_status
+        :return: tuple
+        :rtype: tuple
         """
-        return self.vis_property_set.GetRealColor(o_red, o_green, o_blue)
+        return self.vis_property_set.GetRealColor()
 
-    def get_real_inheritance(self, i_property_type, o_inheritance):
+    def get_real_inheritance(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetRealInheritance(CatVisPropertyType iPropertyType,
                 | long oInheritance) As CatVisPropertyStatus
                 | 
@@ -256,32 +249,25 @@ class VisPropertySet(AnyObject):
                 | 
                 |         iPropertyType
                 |             The type of property: Color, Opacity, Line Width, Line Type
-                |             
                 |         oInheritance
-                | 
                 |             0
                 |                 No heritance 
                 |             1
                 |                 Heritance 
-                | 
                 |         oStatus
                 |             Legal value:
-                | 
                 |             catVisPropertyDefined
                 |                 All elements in the current selection have the same real
                 |                 inheritance flag for the iPropertyType , so oInheritance is valid
-                |                 
                 |             catVisPropertyUnDefined
                 |                 The real inheritance flag for iPropertyType is not the same for
                 |                 all elements of the current selection, so oInheritance is not valid
-                |                 
-                | 
+                |
                 |     Example:
                 | 
                 |           The following sample shows how to retrieve inheritance of current
                 |           selection.
-                |          
-                | 
+                |
                 |          Dim inhLineType, inhWidth, inhColor, inhOpacity
                 |          inhLineType = CLng(0) 
                 |          inhWidth = CLng(0) 
@@ -299,16 +285,15 @@ class VisPropertySet(AnyObject):
                 |          MsgBox "Inheritance : linetype = " & inhLineType & "width =" & inhWidth & "Colour ="
                 |                 & inhColor & "Opacity =" & inhOpacity
 
-        :param CatVisPropertyType i_property_type:
-        :param int o_inheritance:
-        :return: enum cat_vis_property_status
+        :return: tuple
+        :rtype: tuple
         """
-        return self.vis_property_set.GetRealInheritance(i_property_type.com_object, o_inheritance)
+        return self.vis_property_set.GetRealInheritance()
 
-    def get_real_line_type(self, o_line_type):
+    def get_real_line_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetRealLineType(long oLineType) As
                 | CatVisPropertyStatus
                 | 
@@ -345,15 +330,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetRealLineType linetype
                 |          MsgBox "linetype = " & linetype
 
-        :param int o_line_type:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetRealLineType(o_line_type)
+        return self.vis_property_set.GetRealLineType()
 
-    def get_real_opacity(self, o_opacity):
+    def get_real_opacity(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetRealOpacity(long oOpacity) As CatVisPropertyStatus
                 | 
                 |     Retrieves the real opacity for the current selection.
@@ -388,15 +373,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetRealOpacity op 
                 |          MsgBox "opacity = " & op
 
-        :param int o_opacity:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetRealOpacity(o_opacity)
+        return self.vis_property_set.GetRealOpacity()
 
-    def get_real_width(self, o_line_width):
+    def get_real_width(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetRealWidth(long oLineWidth) As CatVisPropertyStatus
                 | 
                 |     Retrieves the real line width for the current selection.
@@ -432,15 +417,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetRealWidth width
                 |          MsgBox "width = " & width
 
-        :param int o_line_width:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetRealWidth(o_line_width)
+        return self.vis_property_set.GetRealWidth()
 
-    def get_show(self, o_show):
+    def get_show(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetShow(CatVisPropertyShow oShow) As
                 | CatVisPropertyStatus
                 | 
@@ -458,15 +443,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetShow showstate
                 |          MsgBox "show = " & showstate
 
-        :param CatVisPropertyShow o_show:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetShow(o_show.com_object)
+        return self.vis_property_set.GetShow()
 
-    def get_symbol_type(self, o_symbol_type):
+    def get_symbol_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetSymbolType(long oSymbolType) As
                 | CatVisPropertyStatus
                 | 
@@ -474,10 +459,8 @@ class VisPropertySet(AnyObject):
                 | 
                 |     Parameters:
                 | 
-                |         oSymbolType
-                |             The symbol type. See 
-                | 
-                |         SetSymbolType to have values. 
+                |     oSymbolType
+                |         The symbol type. See SetSymbolType to have values.
                 |     oStatus
                 |         Legal value:
                 | 
@@ -503,15 +486,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetSymbolType symbol
                 |          MsgBox "Symbol = " & symbol
 
-        :param int o_symbol_type:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetSymbolType(o_symbol_type)
+        return self.vis_property_set.GetSymbolType()
 
-    def get_visible_color(self, o_red, o_green, o_blue):
+    def get_visible_color(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetVisibleColor(long oRed,
                 | long oGreen,
                 | long oBlue) As CatVisPropertyStatus
@@ -552,17 +535,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetVisibleColor r, g, b 
                 |          MsgBox "r = " & r & " g = " & g & " b = " & b
 
-        :param int o_red:
-        :param int o_green:
-        :param int o_blue:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetVisibleColor(o_red, o_green, o_blue)
+        return self.vis_property_set.GetVisibleColor()
 
-    def get_visible_inheritance(self, i_property_type, o_inheritance):
+    def get_visible_inheritance(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetVisibleInheritance(CatVisPropertyType
                 | iPropertyType,
                 | long oInheritance) As CatVisPropertyStatus
@@ -593,16 +574,15 @@ class VisPropertySet(AnyObject):
                 |                 The inheritance flag for iPropertyType is not the same for all
                 |                 elements of the current selection, so oInheritance is not valid
 
-        :param CatVisPropertyType i_property_type:
-        :param int o_inheritance:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetVisibleInheritance(i_property_type.com_object, o_inheritance)
+        return self.vis_property_set.GetVisibleInheritance()
 
-    def get_visible_line_type(self, o_line_type):
+    def get_visible_line_type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetVisibleLineType(long oLineType) As
                 | CatVisPropertyStatus
                 | 
@@ -638,15 +618,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetVisibleLineType linetype
                 |          MsgBox "linetype = " & linetype
 
-        :param int o_line_type:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetVisibleLineType(o_line_type)
+        return self.vis_property_set.GetVisibleLineType()
 
-    def get_visible_opacity(self, o_opacity):
+    def get_visible_opacity(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetVisibleOpacity(long oOpacity) As
                 | CatVisPropertyStatus
                 | 
@@ -684,15 +664,15 @@ class VisPropertySet(AnyObject):
                 |          visProperties1.GetVisibleOpacity op 
                 |          MsgBox "opacity = " & op
 
-        :param int o_opacity:
-        :return: enum cat_vis_property_status
+        :return: int
+        :rtype: int
         """
-        return self.vis_property_set.GetVisibleOpacity(o_opacity)
+        return self.vis_property_set.GetVisibleOpacity()
 
-    def get_visible_width(self, o_line_width):
+    def get_visible_width(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetVisibleWidth(long oLineWidth) As
                 | CatVisPropertyStatus
                 | 
@@ -720,23 +700,23 @@ class VisPropertySet(AnyObject):
                 | 
                 |           The following sample shows how to retrieve displayed line width of
                 |           current selection.
-                |          
-                | 
+                |
                 |          Dim width
                 |          width = CLng(0) 
                 |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                 |          visProperties1.GetVisibleWidth width
                 |          MsgBox "width = " & width
 
-        :param int o_line_width:
-        :return: enum cat_vis_property_status
-        """
-        return self.vis_property_set.GetVisibleWidth(o_line_width)
 
-    def set_layer(self, i_layer_type, i_layer_value):
+        :return: int
+        :rtype: int
+        """
+        return self.vis_property_set.GetVisibleWidth()
+
+    def set_layer(self, i_layer_type: int, i_layer_value: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetLayer(CatVisLayerType iLayerType,
                 | long iLayerValue)
                 | 
@@ -761,31 +741,17 @@ class VisPropertySet(AnyObject):
                 |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                 |          visProperties1.SetLayer catVisLayerBasic, 100
 
-        :param CatVisLayerType i_layer_type:
+        :param int i_layer_type:
         :param int i_layer_value:
         :return: None
+        :rtype: None
         """
-        return self.vis_property_set.SetLayer(i_layer_type.com_object, i_layer_value)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'set_layer'
-        # # vba_code = """
-        # # Public Function set_layer(vis_property_set)
-        # #     Dim iLayerType (2)
-        # #     vis_property_set.SetLayer iLayerType
-        # #     set_layer = iLayerType
-        # # End Function
-        # # """
+        return self.vis_property_set.SetLayer(i_layer_type, i_layer_value)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def set_pick(self, i_pick):
+    def set_pick(self, i_pick: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetPick(CatVisPropertyPick iPick)
                 | 
                 |     Sets the state pick mode for the current selection.
@@ -800,30 +766,16 @@ class VisPropertySet(AnyObject):
                 |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                 |          visProperties1.SetPick catVisPropertyNoPickAttr
 
-        :param CatVisPropertyPick i_pick:
+        :param int i_pick:
         :return: None
+        :rtype: None
         """
-        return self.vis_property_set.SetPick(i_pick.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'set_pick'
-        # # vba_code = """
-        # # Public Function set_pick(vis_property_set)
-        # #     Dim iPick (2)
-        # #     vis_property_set.SetPick iPick
-        # #     set_pick = iPick
-        # # End Function
-        # # """
+        return self.vis_property_set.SetPick(i_pick)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def set_real_color(self, i_red, i_green, i_blue, i_inheritance):
+    def set_real_color(self, i_red: int, i_green: int, i_blue: int, i_inheritance: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetRealColor(long iRed,
                 | long iGreen,
                 | long iBlue,
@@ -862,13 +814,14 @@ class VisPropertySet(AnyObject):
         :param int i_blue:
         :param int i_inheritance:
         :return: None
+        :rtype: None
         """
         return self.vis_property_set.SetRealColor(i_red, i_green, i_blue, i_inheritance)
 
-    def set_real_line_type(self, i_line_type, i_inheritance):
+    def set_real_line_type(self, i_line_type: int, i_inheritance: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetRealLineType(long iLineType,
                 | long iInheritance)
                 | 
@@ -891,23 +844,22 @@ class VisPropertySet(AnyObject):
                 | 
                 |     Example:
                 | 
-                |           The following sample shows how to change line type of current
-                |           selection.
-                |          
-                | 
-                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
-                |          visProperties1.SetRealLineType 4,1
+                |     The following sample shows how to change line type of current
+                |     selection.
+                |       Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties
+                |       visProperties1.SetRealLineType 4,1
 
         :param int i_line_type:
         :param int i_inheritance:
         :return: None
+        :rtype: None
         """
         return self.vis_property_set.SetRealLineType(i_line_type, i_inheritance)
 
-    def set_real_opacity(self, i_opacity, i_inheritance):
+    def set_real_opacity(self, i_opacity: int, i_inheritance: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetRealOpacity(long iOpacity,
                 | long iInheritance)
                 | 
@@ -937,13 +889,14 @@ class VisPropertySet(AnyObject):
         :param int i_opacity:
         :param int i_inheritance:
         :return: None
+        :rtype: None
         """
         return self.vis_property_set.SetRealOpacity(i_opacity, i_inheritance)
 
-    def set_real_width(self, i_line_width, i_inheritance):
+    def set_real_width(self, i_line_width: int, i_inheritance: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetRealWidth(long iLineWidth,
                 | long iInheritance)
                 | 
@@ -976,13 +929,14 @@ class VisPropertySet(AnyObject):
         :param int i_line_width:
         :param int i_inheritance:
         :return: None
+        :rtype: None
         """
         return self.vis_property_set.SetRealWidth(i_line_width, i_inheritance)
 
-    def set_show(self, i_show):
+    def set_show(self, i_show: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetShow(CatVisPropertyShow iShow)
                 | 
                 |     Sets the state show mode for the current selection.
@@ -997,30 +951,16 @@ class VisPropertySet(AnyObject):
                 |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                 |          visProperties1.SetShow catVisPropertyNoShowAttr
 
-        :param CatVisPropertyShow i_show:
+        :param int i_show:
         :return: None
+        :rtype: None
         """
-        return self.vis_property_set.SetShow(i_show.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'set_show'
-        # # vba_code = """
-        # # Public Function set_show(vis_property_set)
-        # #     Dim iShow (2)
-        # #     vis_property_set.SetShow iShow
-        # #     set_show = iShow
-        # # End Function
-        # # """
+        return self.vis_property_set.SetShow(i_show)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def set_symbol_type(self, i_symbol_type):
+    def set_symbol_type(self, i_symbol_type: int) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetSymbolType(long iSymbolType)
                 | 
                 |     Sets the symbol type.
@@ -1052,16 +992,15 @@ class VisPropertySet(AnyObject):
                 |                 FULLSQUARE2 : a big 13
                 | 
                 |     Example:
-                | 
-                |           The following sample shows how to change symbol type of current
-                |           selection.
-                |          
-                | 
-                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
-                |          visProperties1.SetSymbolType 4
+                |     The following sample shows how to change symbol type of current
+                |     selection.
+                |
+                |       Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties
+                |       visProperties1.SetSymbolType 4
 
         :param int i_symbol_type:
         :return: None
+        :rtype: None
         """
         return self.vis_property_set.SetSymbolType(i_symbol_type)
 
