@@ -11,10 +11,10 @@
 
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class List(Collection):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -34,7 +34,7 @@ class List(Collection):
         super().__init__(com_object)
         self.list = com_object
 
-    def add(self, i_item_value):
+    def add(self, i_item_value: AnyObject) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -46,10 +46,11 @@ class List(Collection):
 
         :param AnyObject i_item_value:
         :return: None
+        :rtype: None
         """
         return self.list.Add(i_item_value.com_object)
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> AnyObject:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -77,12 +78,13 @@ class List(Collection):
                 |          Dim lastFeature As CATIABase
                 |          Set lastFeature = Features.Item(Features.Count)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: AnyObject
+        :rtype: AnyObject
         """
         return AnyObject(self.list.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -109,25 +111,11 @@ class List(Collection):
 
         :param CATVariant i_index:
         :return: None
+        :rtype: None
         """
         return self.list.Remove(i_index)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(list)
-        # #     Dim iIndex (2)
-        # #     list.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def reorder(self, i_index_current, i_index_target):
+    def reorder(self, i_index_current: cat_variant, i_index_target: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -138,28 +126,14 @@ class List(Collection):
                 |     position. Doesn't change the list if either position is out of the list. Return
                 |     E_FAIL if cannot reorder.
 
-        :param CATVariant i_index_current:
-        :param CATVariant i_index_target:
+        :param cat_variant i_index_current:
+        :param cat_variant i_index_target:
         :return: None
+        :rtype: None
         """
         return self.list.Reorder(i_index_current.com_object, i_index_target.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'reorder'
-        # # vba_code = """
-        # # Public Function reorder(list)
-        # #     Dim iIndexCurrent (2)
-        # #     list.Reorder iIndexCurrent
-        # #     reorder = iIndexCurrent
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def replace(self, i_index, i_item_value):
+    def replace(self, i_index: cat_variant, i_item_value: AnyObject) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -171,26 +145,12 @@ class List(Collection):
                 |     E_FAIL if trying to set an already existing element while
                 |     IsDuplicateElementsAllowed is false.
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :param AnyObject i_item_value:
         :return: None
+        :rtype: None
         """
         return self.list.Replace(i_index, i_item_value.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'replace'
-        # # vba_code = """
-        # # Public Function replace(list)
-        # #     Dim iIndex (2)
-        # #     list.Replace iIndex
-        # #     replace = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'List(name="{ self.name }")'
+        return f'List(name="{self.name}")'
