@@ -8,9 +8,10 @@
         and thus help debugging in pycatia.
 
 """
-
+from pycatia.in_interfaces.reference import Reference
 from pycatia.mec_mod_interfaces.constraint import Constraint
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class Constraints(Collection):
@@ -37,54 +38,56 @@ class Constraints(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=Constraint)
         self.constraints = com_object
 
     @property
-    def broken_constraints_count(self):
+    def broken_constraints_count(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property BrokenConstraintsCount() As long (Read Only)
                 | 
                 |     Returns the number of broken constraints from the Constraints
                 |     collection.
-                |
+                | 
                 |     Example:
                 |         The following example retrieves in BknCstNum the number of broken
                 |         constraints from the myListofConstraints collection of
                 |         constraints:
-                |
+                | 
                 |          BknCstNum = myListofConstraints.BrokenConstraintsCount
 
         :return: int
+        :rtype: int
         """
 
         return self.constraints.BrokenConstraintsCount
 
     @property
-    def un_updated_constraints_count(self):
+    def un_updated_constraints_count(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property UnUpdatedConstraintsCount() As long (Read Only)
                 | 
                 |     Returns the number of unupdated constraints from the Constraints
                 |     collection.
-                |
+                | 
                 |     Example:
                 |         The following example retrieves in UnUpdCstNum the number of unupdated
                 |         constraints from the myListofConstraints collection of
                 |         constraints:
-                |
+                | 
                 |          UnUpdCstNum = myListofConstraints.UnUpdatedConstraintsCount
 
         :return: int
+        :rtype: int
         """
 
         return self.constraints.UnUpdatedConstraintsCount
 
-    def add_bi_elt_cst(self, i_cst_type=None, i_first_elem=None, i_second_elem=None):
+    def add_bi_elt_cst(self, i_cst_type: int, i_first_elem: Reference, i_second_elem: Reference) -> Constraint:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -115,15 +118,15 @@ class Constraints(Collection):
                 |
                 |      Set newCst = skCstList.AddBiEltCst(4, c1, c2)
 
-        :param CatConstraintType i_cst_type:
+        :param int i_cst_type:
         :param Reference i_first_elem:
         :param Reference i_second_elem:
         :return: Constraint
+        :rtype: Constraint
         """
-        return Constraint(
-            self.constraints.AddBiEltCst(i_cst_type, i_first_elem.com_object, i_second_elem.com_object))
+        return Constraint(self.constraints.AddBiEltCst(i_cst_type, i_first_elem.com_object, i_second_elem.com_object))
 
-    def add_mono_elt_cst(self, i_cst_type=None, i_elem=None):
+    def add_mono_elt_cst(self, i_cst_type: int, i_elem: Reference) -> Constraint:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -151,13 +154,15 @@ class Constraints(Collection):
                 |
                 |      Set NewCst = cstList.AddMonoEltCst(0, P1)
 
-        :param CatConstraintType i_cst_type:
+        :param int i_cst_type:
         :param Reference i_elem:
         :return: Constraint
+        :rtype: Constraint
         """
         return Constraint(self.constraints.AddMonoEltCst(i_cst_type, i_elem.com_object))
 
-    def add_tri_elt_cst(self, i_cst_type=None, i_first_elem=None, i_second_elem=None, i_third_elem=None):
+    def add_tri_elt_cst(self, i_cst_type: int, i_first_elem: Reference, i_second_elem: Reference,
+                        i_third_elem: Reference) -> Constraint:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -192,17 +197,17 @@ class Constraints(Collection):
                 |
                 |      Set symCst = prtCstList.AddTriEltCst(15, cyl1, cyl2, symPlane)
 
-        :param CatConstraintType i_cst_type:
+        :param int i_cst_type:
         :param Reference i_first_elem:
         :param Reference i_second_elem:
         :param Reference i_third_elem:
         :return: Constraint
+        :rtype: Constraint
         """
-        return Constraint(
-            self.constraints.AddTriEltCst(i_cst_type.com_object, i_first_elem.com_object, i_second_elem.com_object,
-                                          i_third_elem.com_object))
+        return Constraint(self.constraints.AddTriEltCst(i_cst_type, i_first_elem.com_object, i_second_elem.com_object,
+                                                        i_third_elem.com_object))
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> Constraint:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -231,12 +236,13 @@ class Constraints(Collection):
                 |          Set cst1 = cstList.Item(1)
                 |          Set cst2 = cstList.Item("Constraint.2")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: Constraint
+        :rtype: Constraint
         """
         return Constraint(self.constraints.Item(i_index))
 
-    def remove(self, i_index):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -261,8 +267,9 @@ class Constraints(Collection):
                 | 
                 |      cstList.Remove(cstList.Count)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
         return self.constraints.Remove(i_index)
 
