@@ -11,12 +11,13 @@
 
 from pycatia.product_structure_interfaces.product import Product
 from pycatia.system_interfaces.any_object import AnyObject
+from pycatia.types import cat_variant
 
 
 class FixTogether(AnyObject):
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -37,10 +38,10 @@ class FixTogether(AnyObject):
         self.fix_together = com_object
 
     @property
-    def fix_togethers_count(self):
+    def fix_togethers_count(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property FixTogethersCount() As long (Read Only)
                 | 
                 |     Returns the number of FixTogether entities in the
@@ -53,15 +54,16 @@ class FixTogether(AnyObject):
                 |          fixTogethersCount = myFixTogether.FixTogethersCount
 
         :return: int
+        :rtype: int
         """
 
         return self.fix_together.FixTogethersCount
 
     @property
-    def products_count(self):
+    def products_count(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property ProductsCount() As long (Read Only)
                 | 
                 |     Returns the number of products fixed together in the
@@ -74,14 +76,15 @@ class FixTogether(AnyObject):
                 |          productsCount = myFixTogether.ProductsCount
 
         :return: int
+        :rtype: int
         """
 
         return self.fix_together.ProductsCount
 
-    def add_fix_together(self, i_fix_together=None):
+    def add_fix_together(self, i_fix_together: 'FixTogether') -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddFixTogether(FixTogether iFixTogether)
                 | 
                 |     Add a fixTogether to a FixTogether. The fixTogether is fixed together with
@@ -95,6 +98,7 @@ class FixTogether(AnyObject):
 
         :param FixTogether i_fix_together:
         :return: None
+        :rtype: None
         """
         return self.fix_together.AddFixTogether(i_fix_together.com_object)
         # # # # Autogenerated comment: 
@@ -113,10 +117,10 @@ class FixTogether(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_product(self, i_product=None):
+    def add_product(self, i_product: Product) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AddProduct(Product iProduct)
                 | 
                 |     Add a product to a FixTogether. The product is fixed together with the
@@ -130,6 +134,7 @@ class FixTogether(AnyObject):
 
         :param Product i_product:
         :return: None
+        :rtype: None
         """
         return self.fix_together.AddProduct(i_product.com_object)
         # # # # Autogenerated comment: 
@@ -148,10 +153,10 @@ class FixTogether(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_fix_together(self, i_index=None):
+    def get_fix_together(self, i_index: cat_variant) -> 'FixTogether':
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetFixTogether(CATVariant iIndex) As FixTogether
                 | 
                 |     Returns a FixTogether using its index or its name in the
@@ -163,7 +168,7 @@ class FixTogether(AnyObject):
                 |             The index or the name of the FixTogether to retrieve. As a
                 |             numerics, this index is the rank of the FixTogether in the FixTogethers of the
                 |             FixTogether. The index of the first FixTogether is 1, and the index of the last
-                |             FixTogether is FixTogethersCount. As a string, it is the name you assigned to
+                |             FixTogether is FixTogether sCount. As a string, it is the name you assigned to
                 |             the FixTogether using the 
                 | 
                 |         AnyObject.Name property. 
@@ -179,15 +184,16 @@ class FixTogether(AnyObject):
                 |          Dim thatFixTogether As FixTogether
                 |          Set thatFixTogether = myFixTogether.GetFixTogether("myFixTogether")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: FixTogether
+        :rtype: FixTogether
         """
-        return FixTogether(self.fix_together.GetFixTogether(i_index.com_object))
+        return FixTogether(self.fix_together.GetFixTogether(i_index))
 
-    def get_product(self, i_index=None):
+    def get_product(self, i_index: cat_variant) -> Product:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetProduct(CATVariant iIndex) As Product
                 | 
                 |     Returns a Product using its index or its name in the
@@ -215,15 +221,16 @@ class FixTogether(AnyObject):
                 |          Dim thatProduct As Product
                 |          Set thatProduct = myFixTogether.GetProduct("myProduct")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: Product
+        :rtype: Product
         """
-        return Product(self.fix_together.GetProduct(i_index.com_object))
+        return Product(self.fix_together.GetProduct(i_index))
 
-    def remove_fix_together(self, i_index=None):
+    def remove_fix_together(self, i_index: cat_variant) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveFixTogether(CATVariant iIndex)
                 | 
                 |     Removes a FixTogether from the FixTogether.
@@ -245,30 +252,16 @@ class FixTogether(AnyObject):
                 | 
                 |     fixTogether.RemoveFixTogether(fixTogether.FixTogethersCount)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
-        return self.fix_together.RemoveFixTogether(i_index.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove_fix_together'
-        # # vba_code = """
-        # # Public Function remove_fix_together(fix_together)
-        # #     Dim iIndex (2)
-        # #     fix_together.RemoveFixTogether iIndex
-        # #     remove_fix_together = iIndex
-        # # End Function
-        # # """
+        return self.fix_together.RemoveFixTogether(i_index)
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
-
-    def remove_product(self, i_index=None):
+    def remove_product(self, i_index: cat_variant) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub RemoveProduct(CATVariant iIndex)
                 | 
                 |     Removes a Product from the FixTogether.
@@ -289,25 +282,11 @@ class FixTogether(AnyObject):
                 | 
                 |      fixTogether.RemoveProduct(fixTogether.ProductsCount)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
-        return self.fix_together.RemoveProduct(i_index.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove_product'
-        # # vba_code = """
-        # # Public Function remove_product(fix_together)
-        # #     Dim iIndex (2)
-        # #     fix_together.RemoveProduct iIndex
-        # #     remove_product = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        return self.fix_together.RemoveProduct(i_index)
 
     def __repr__(self):
         return f'FixTogether(name="{self.name}")'
