@@ -11,6 +11,7 @@
 
 from pycatia.mec_mod_interfaces.fix_together import FixTogether
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class FixTogethers(Collection):
@@ -31,13 +32,13 @@ class FixTogethers(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=FixTogether)
         self.fix_togethers = com_object
 
-    def add(self):
+    def add(self) -> FixTogether:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Add() As FixTogether
                 | 
                 |     Creates a new FixTogether and adds it to the FixTogethers
@@ -52,13 +53,14 @@ class FixTogethers(Collection):
                 |          Set newFixTogether = fixTogethers.Add
 
         :return: FixTogether
+        :rtype: FixTogether
         """
         return FixTogether(self.fix_togethers.Add())
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> FixTogether:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Item(CATVariant iIndex) As FixTogether
                 | 
                 |     Returns a FixTogether using its index or its name from the FixTogethers
@@ -86,15 +88,16 @@ class FixTogethers(Collection):
                 |          Set thisFixTogether = fixTogetherColl.Item(5)
                 |          Set thatFixTogether = fixTogetherColl.Item("MyFixTogether")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: FixTogether
+        :rtype: FixTogether
         """
         return FixTogether(self.fix_togethers.Item(i_index))
 
-    def remove(self, i_index=None):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub Remove(CATVariant iIndex)
                 | 
                 |     Removes a FixTogether from the FixTogethers collection.
@@ -117,25 +120,11 @@ class FixTogethers(Collection):
                 | 
                 |      fixTogetherColl.Remove(fixTogetherColl.Count)
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
-        return self.fix_togethers.Remove(i_index.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(fix_togethers)
-        # #     Dim iIndex (2)
-        # #     fix_togethers.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        return self.fix_togethers.Remove(i_index)
 
     def __repr__(self):
         return f'FixTogethers(name="{self.name}")'
