@@ -33,10 +33,10 @@ class HybridShape(AnyObject):
         self.hybrid_shape = com_object
 
     @property
-    def thickness(self):
+    def thickness(self) -> 'HybridShape':
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Thickness() As HybridShape (Read Only)
                 | 
                 |     Returns the thickness of the hybrid shape.
@@ -53,14 +53,15 @@ class HybridShape(AnyObject):
                 |          Set Thickness1 = Extrude1.Thickness
 
         :return: HybridShape
+        :rtype: HybridShape
         """
 
         return HybridShape(self.hybrid_shape.Thickness)
 
-    def append_hybrid_shape(self, i_hybrid_shape=None):
+    def append_hybrid_shape(self, i_hybrid_shape: 'HybridShape') -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub AppendHybridShape(HybridShape iHybridShape)
                 | 
                 |     Appends a hybrid shape to another hybrid shape.
@@ -78,6 +79,7 @@ class HybridShape(AnyObject):
 
         :param HybridShape i_hybrid_shape:
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape.AppendHybridShape(i_hybrid_shape.com_object)
         # # # # Autogenerated comment: 
@@ -96,7 +98,7 @@ class HybridShape(AnyObject):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def compute(self):
+    def compute(self) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -105,6 +107,7 @@ class HybridShape(AnyObject):
                 |     Computes the result of the hybrid shape.
 
         :return: None
+        :rtype: None
         """
         return self.hybrid_shape.Compute()
 
