@@ -12,6 +12,7 @@
 from pycatia.mec_mod_interfaces.boundary import Boundary
 from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class HybridShapes(Collection):
@@ -31,13 +32,13 @@ class HybridShapes(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=HybridShape)
         self.hybrid_shapes = com_object
 
-    def get_boundary(self, i_label=None):
+    def get_boundary(self, i_label: str) -> Boundary:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetBoundary(CATBSTR iLabel) As Boundary
                 | 
                 |     Returns a boundary using its label.
@@ -53,13 +54,14 @@ class HybridShapes(Collection):
 
         :param str i_label:
         :return: Boundary
+        :rtype: Boundary
         """
         return Boundary(self.hybrid_shapes.GetBoundary(i_label))
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> HybridShape:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Item(CATVariant iIndex) As HybridShape
                 | 
                 |     Returns a HybridShape using its index or its name from the HybridShapes
@@ -87,8 +89,9 @@ class HybridShapes(Collection):
                 |          Set ThisHybridShape = CATIA.ActiveDocument.HybridShapes.Item(3)
                 |          Set ThatHybridShape = CATIA.ActiveDocument.HybridShapes.Item("MyHybridShape")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: HybridShape
+        :rtype: HybridShape
         """
         return HybridShape(self.hybrid_shapes.Item(i_index))
 
