@@ -39,10 +39,10 @@ class OrderedGeometricalSet(AnyObject):
         self.ordered_geometrical_set = com_object
 
     @property
-    def bodies(self):
+    def bodies(self) -> 'Bodies':
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Bodies() As Bodies (Read Only)
                 | 
                 |     Returns the ordered geometrical set's Bodies collection.
@@ -54,12 +54,13 @@ class OrderedGeometricalSet(AnyObject):
                 |          Set bodyColl = OrderedGeometricalSet1.Bodies
 
         :return: Bodies
+        :rtype: Bodies
         """
         from pycatia.mec_mod_interfaces.bodies import Bodies
         return Bodies(self.ordered_geometrical_set.Bodies)
 
     @property
-    def hybrid_shapes(self):
+    def hybrid_shapes(self) -> HybridShapes:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -83,15 +84,16 @@ class OrderedGeometricalSet(AnyObject):
                 |              Set HybridShapes1 = OrderedGeometricalSet1.HybridShapes
 
         :return: HybridShapes
+        :rtype: HybridShapes
         """
 
         return HybridShapes(self.ordered_geometrical_set.HybridShapes)
 
     @property
-    def ordered_geometrical_sets(self):
+    def ordered_geometrical_sets(self) -> 'OrderedGeometricalSets':
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property OrderedGeometricalSets() As OrderedGeometricalSets (Read
                 | Only)
                 | 
@@ -106,12 +108,13 @@ class OrderedGeometricalSet(AnyObject):
                 |          Set OrderedGeometricalSetColl = OrderedGeometricalSet1.OrderedGeometricalSets
 
         :return: OrderedGeometricalSets
+        :rtype: OrderedGeometricalSets
         """
         from pycatia.mec_mod_interfaces.ordered_geometrical_sets import OrderedGeometricalSets
         return OrderedGeometricalSets(self.ordered_geometrical_set.OrderedGeometricalSets)
 
     @property
-    def ordered_sketches(self):
+    def ordered_sketches(self) -> Sketches:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -128,14 +131,15 @@ class OrderedGeometricalSet(AnyObject):
                 |          Set sketchesCollection = OrderedGeometricalSet1.OrderedSketches
 
         :return: Sketches
+        :rtype: Sketches
         """
 
         return Sketches(self.ordered_geometrical_set.OrderedSketches)
 
-    def insert_hybrid_shape(self, i_hybrid_shape=None):
+    def insert_hybrid_shape(self, i_hybrid_shape: 'HybridShape') -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub InsertHybridShape(HybridShape iHybridShape)
                 | 
                 |     Inserts a hybrid shape to the ordered geometrical set.
@@ -154,6 +158,7 @@ class OrderedGeometricalSet(AnyObject):
 
         :param HybridShape i_hybrid_shape:
         :return: None
+        :rtype: None
         """
         return self.ordered_geometrical_set.InsertHybridShape(i_hybrid_shape.com_object)
         # # # # Autogenerated comment: 
