@@ -11,6 +11,7 @@
 
 from pycatia.mec_mod_interfaces.ordered_geometrical_set import OrderedGeometricalSet
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class OrderedGeometricalSets(Collection):
@@ -30,13 +31,13 @@ class OrderedGeometricalSets(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=OrderedGeometricalSet)
         self.ordered_geometrical_sets = com_object
 
-    def add(self):
+    def add(self) -> OrderedGeometricalSet:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Add() As OrderedGeometricalSet
                 | 
                 |     Creates a new ordered geometrical set and adds it to the
@@ -54,13 +55,14 @@ class OrderedGeometricalSets(Collection):
                 |          Set NewPartBody = rootPart.OrderedGeometricalSets.Add()
 
         :return: OrderedGeometricalSet
+        :rtype: OrderedGeometricalSet
         """
         return OrderedGeometricalSet(self.ordered_geometrical_sets.Add())
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> OrderedGeometricalSet:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Item(CATVariant iIndex) As OrderedGeometricalSet
                 | 
                 |     Returns a ordered geometrical set using its index or its name from the
@@ -89,8 +91,9 @@ class OrderedGeometricalSets(Collection):
                 |          Set ThisOrderedGeometricalSet = orderedGeometricalSetColl.Item(5)
                 |          Set ThatOrderedGeometricalSet = orderedGeometricalSetColl.Item("MyOrderedGeometricalSet")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: OrderedGeometricalSet
+        :rtype: OrderedGeometricalSet
         """
         return OrderedGeometricalSet(self.ordered_geometrical_sets.Item(i_index))
 
