@@ -12,6 +12,7 @@
 from pycatia.mec_mod_interfaces.boundary import Boundary
 from pycatia.mec_mod_interfaces.shape import Shape
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class Shapes(Collection):
@@ -31,13 +32,13 @@ class Shapes(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=Shape)
         self.shapes = com_object
 
-    def get_boundary(self, i_label=None):
+    def get_boundary(self, i_label: str) -> Boundary:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func GetBoundary(CATBSTR iLabel) As Boundary
                 | 
                 |     Returns a boundary using its label.
@@ -53,13 +54,14 @@ class Shapes(Collection):
 
         :param str i_label:
         :return: Boundary
+        :rtype: Boundary
         """
         return Boundary(self.shapes.GetBoundary(i_label))
 
-    def item(self, i_index):
+    def item(self, i_index: cat_variant) -> Shape:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Item(CATVariant iIndex) As Shape
                 | 
                 |     Returns a shape using its index or its name from the Shapes
@@ -85,8 +87,9 @@ class Shapes(Collection):
                 |          Set ThisShape = CATIA.ActiveDocument.Shapes.Item(3)
                 |          Set ThatShape = CATIA.ActiveDocument.Shapes.Item("MyShape")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: Shape
+        :rtype: Shape
         """
         return Shape(self.shapes.Item(i_index))
 
