@@ -11,10 +11,10 @@
 
 from pycatia.product_structure_interfaces.product import Product
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class Products(Collection):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -34,10 +34,10 @@ class Products(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=Product)
         self.products = com_object
 
-    def add_component(self, i_reference_product=None):
+    def add_component(self, i_reference_product: Product) -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -66,10 +66,11 @@ class Products(Collection):
 
         :param Product i_reference_product:
         :return: Product
+        :rtype: Product
         """
         return Product(self.products.AddComponent(i_reference_product.com_object))
 
-    def add_components_from_files(self, i_files_list=None, i_method=None):
+    def add_components_from_files(self, i_files_list: tuple, i_method: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -90,6 +91,7 @@ class Products(Collection):
         :param tuple i_files_list:
         :param str i_method:
         :return: None
+        :rtype: None
         """
         return self.products.AddComponentsFromFiles(i_files_list, i_method)
         # # # # Autogenerated comment:
@@ -108,7 +110,7 @@ class Products(Collection):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def add_external_component(self, i_product_document=None):
+    def add_external_component(self, i_product_document: 'Document') -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -138,10 +140,11 @@ class Products(Collection):
 
         :param Document i_product_document:
         :return: Product
+        :rtype: Product
         """
         return Product(self.products.AddExternalComponent(i_product_document.com_object))
 
-    def add_new_component(self, i_documen_type=None, i_part_number=None):
+    def add_new_component(self, i_documen_type: str, i_part_number: str) -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -175,7 +178,7 @@ class Products(Collection):
         """
         return Product(self.products.AddNewComponent(i_documen_type, i_part_number))
 
-    def add_new_product(self, i_part_number=None):
+    def add_new_product(self, i_part_number: str) -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -203,10 +206,11 @@ class Products(Collection):
 
         :param str i_part_number:
         :return: Product
+        :rtype: Product
         """
         return Product(self.products.AddNewProduct(i_part_number))
 
-    def item(self, i_index=None):
+    def item(self, i_index: cat_variant) -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -241,12 +245,13 @@ class Products(Collection):
                 |          Dim ThatProduct As Product
                 |          Set ThatProduct = CarParts.Item("Wheel")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: Product
+        :rtype: Product
         """
-        return Product(self.products.Item(i_index.com_object))
+        return Product(self.products.Item(i_index))
 
-    def remove(self, i_index=None):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -275,10 +280,11 @@ class Products(Collection):
                 |          Brakes.Remove(6)
                 |          Brakes.Remove("LeftRearDisc")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
-        return self.products.Remove(i_index.com_object)
+        return self.products.Remove(i_index)
         # # # # Autogenerated comment:
         # # some methods require a system service call as the methods expects a vb array object
         # # passed to it and there is no way to do this directly with python. In those cases the following code
@@ -295,7 +301,7 @@ class Products(Collection):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def replace_component(self, i_old_component=None, i_file_path=None, i_multi_instances=None):
+    def replace_component(self, i_old_component: Product, i_file_path: str, i_multi_instances: bool) -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -325,10 +331,11 @@ class Products(Collection):
         :param str i_file_path:
         :param bool i_multi_instances:
         :return: Product
+        :rtype: Product
         """
         return Product(self.products.ReplaceComponent(i_old_component.com_object, i_file_path, i_multi_instances))
 
-    def replace_product(self, i_old_component=None, i_new_reference=None, i_multi_instances=None):
+    def replace_product(self, i_old_component: Product, i_new_reference: Product, i_multi_instances: bool) -> Product:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -354,6 +361,7 @@ class Products(Collection):
         :param Product i_new_reference:
         :param bool i_multi_instances:
         :return: Product
+        :rtype: Product
         """
         return Product(
             self.products.ReplaceProduct(
@@ -364,4 +372,4 @@ class Products(Collection):
         )
 
     def __repr__(self):
-        return f'Products(name="{ self.name }")'
+        return f'Products(name="{self.name}")'
