@@ -11,10 +11,10 @@
 
 from pycatia.product_structure_interfaces.publication import Publication
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class Publications(Collection):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -36,7 +36,7 @@ class Publications(Collection):
         super().__init__(com_object)
         self.publications = com_object
 
-    def add(self, i_public_name=None):
+    def add(self, i_public_name: str) -> Publication:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -61,10 +61,11 @@ class Publications(Collection):
 
         :param str i_public_name:
         :return: Publication
+        :rtype: Publication
         """
         return Publication(self.publications.Add(i_public_name))
 
-    def item(self, i_identifier=None):
+    def item(self, i_identifier: cat_variant) -> Publication:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -86,12 +87,13 @@ class Publications(Collection):
                 |              Dim Prod1 As Product
                 |              Set Pub1 = Prod1.Item(PubId)
 
-        :param CATVariant i_identifier:
+        :param cat_variant i_identifier:
         :return: Publication
+        :rtype: Publication
         """
-        return Publication(self.publications.Item(i_identifier.com_object))
+        return Publication(self.publications.Item(i_identifier))
 
-    def remove(self, i_identifier=None):
+    def remove(self, i_identifier: str) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -112,10 +114,11 @@ class Publications(Collection):
 
         :param str i_identifier:
         :return: None
+        :rtype: None
         """
         return self.publications.Remove(i_identifier)
 
-    def set_direct(self, i_identifier=None, i_pointed=None):
+    def set_direct(self, i_identifier: cat_variant, i_pointed: 'Reference') -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -142,9 +145,10 @@ class Publications(Collection):
                 |          Dim Prod1 As Product
                 |          Prod1.SetDirect(PubId,RefObject)
 
-        :param CATVariant i_identifier:
+        :param cat_variant i_identifier:
         :param Reference i_pointed:
         :return: None
+        :rtype: None
         """
         return self.publications.SetDirect(i_identifier.com_object, i_pointed.com_object)
         # # # # Autogenerated comment: 
@@ -163,7 +167,7 @@ class Publications(Collection):
         # # system_service = SystemService(self.application.SystemService)
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def set_relay(self, i_identifier=None, i_relayer=None, i_name_in_relay=None):
+    def set_relay(self, i_identifier: cat_variant, i_relayer: 'Publications', i_name_in_relay: cat_variant) -> None:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -191,10 +195,11 @@ class Publications(Collection):
                 |              Dim Prod1 As Product
                 |              Prod1.SetRelay(PubId1,Prod2,PubId2)
 
-        :param CATVariant i_identifier:
+        :param cat_variant i_identifier:
         :param Publications i_relayer:
-        :param CATVariant i_name_in_relay:
+        :param cat_variant i_name_in_relay:
         :return: None
+        :rtype: None
         """
         return self.publications.SetRelay(i_identifier.com_object, i_relayer.com_object, i_name_in_relay.com_object)
         # # # # Autogenerated comment: 
@@ -214,4 +219,4 @@ class Publications(Collection):
         # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
-        return f'Publications(name="{ self.name }")'
+        return f'Publications(name="{self.name}")'
