@@ -10,10 +10,10 @@
 """
 from pycatia.space_analyses_interfaces.distance import Distance
 from pycatia.system_interfaces.collection import Collection
+from pycatia.types import cat_variant
 
 
 class Distances(Collection):
-
     """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -34,10 +34,10 @@ class Distances(Collection):
     """
 
     def __init__(self, com_object):
-        super().__init__(com_object)
+        super().__init__(com_object, child_object=Distance)
         self.distances = com_object
 
-    def add(self):
+    def add(self) -> Distance:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -58,10 +58,11 @@ class Distances(Collection):
                 |             Set NewDistance = TheDistances.Add
 
         :return: Distance
+        :rtype: Distance
         """
         return Distance(self.distances.Add())
 
-    def add_from_sel(self):
+    def add_from_sel(self) -> Distance:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -82,10 +83,11 @@ class Distances(Collection):
                 |             Set NewDistance = TheDistances.AddFromSel
 
         :return: Distance
+        :rtype: Distance
         """
         return Distance(self.distances.AddFromSel())
 
-    def item(self, i_index=None):
+    def item(self, i_index: cat_variant) -> Distance:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
@@ -117,15 +119,16 @@ class Distances(Collection):
                 |             Dim ThatDistance As Distance
                 |             Set ThatDistance = TheDistances.Item("Distance Of MyProduct")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: Distance
+        :rtype: Distance
         """
-        return Distance(self.distances.Item(i_index.com_object))
+        return Distance(self.distances.Item(i_index))
 
-    def remove(self, i_index=None):
+    def remove(self, i_index: cat_variant) -> None:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub Remove(CATVariant iIndex)
                 | 
                 |     Removes a Distance object from the Distances collection.
@@ -150,25 +153,11 @@ class Distances(Collection):
                 |             TheDistances.Remove(10)
                 |             TheDistances.Remove("Distance Of MyProduct")
 
-        :param CATVariant i_index:
+        :param cat_variant i_index:
         :return: None
+        :rtype: None
         """
-        return self.distances.Remove(i_index.com_object)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'remove'
-        # # vba_code = """
-        # # Public Function remove(distances)
-        # #     Dim iIndex (2)
-        # #     distances.Remove iIndex
-        # #     remove = iIndex
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        return self.distances.Remove(i_index)
 
     def __repr__(self):
-        return f'Distances(name="{ self.name }")'
+        return f'Distances(name="{self.name}")'
