@@ -1,5 +1,6 @@
 #! /usr/bin/python3.6
 
+from pycatia.in_interfaces.reference import Reference
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.system_service import SystemService
 
@@ -39,7 +40,7 @@ class Measurable(AnyObject):
         self.measurable = com_object
 
     @property
-    def angle(self):
+    def angle(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic help
@@ -55,11 +56,13 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
+
         return self.measurable.Angle
 
     @property
-    def area(self):
+    def area(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic help
@@ -74,17 +77,18 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
         return self.measurable.Area
 
     @property
-    def geometry_name(self):
+    def geometry_name(self) -> int:
         """
         .. note::
             CAA V5 Visual Basic help
 
-            Property GeometryName( ) As CatMeasurableName (Read Only)
-
+        :return: int
+        :rtype: int
             | Returns the name of the geometry of the measured object.
             | Example:
             | This example retrieves the name of the geometry of the NewMeasurable measure.
@@ -98,7 +102,7 @@ class Measurable(AnyObject):
         return self.measurable.GeometryName
 
     @property
-    def length(self):
+    def length(self) -> float:
         """
         ..note::
             CAA V5 Visual Basic help
@@ -113,12 +117,13 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
 
         return self.measurable.Length
 
     @property
-    def perimeter(self):
+    def perimeter(self) -> float:
         """
         .. note::
             CAA V5 Visual Basic help
@@ -133,12 +138,13 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
 
         return self.measurable.Perimeter
 
     @property
-    def radius(self):
+    def radius(self) -> float:
         """
         ..note ::
             CAA V5 Visual Basic help
@@ -153,12 +159,13 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
 
         return self.measurable.Radius
 
     @property
-    def volume(self):
+    def volume(self) -> float:
         """
         ..note::
             CAA V5 Visual Basic help
@@ -172,15 +179,17 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
+
         return self.measurable.Volume
 
-    def get_angle_between(self, i_measured_item):
+    def get_angle_between(self, i_measured_item: Reference) -> float:
         """
         .. note::
             CAA V5 Visual Basic help
 
-            Func GetAngleBetween( Reference  iMeasuredItem) As double
+        :param Reference i_measured_item:
 
             | Compute the angle between the CATIAMeasurable and another.
             | Example:
@@ -203,6 +212,7 @@ class Measurable(AnyObject):
 
 
         :return: float
+        :rtype: float
         """
 
         return self.measurable.GetAngleBetween(i_measured_item.com_object)
