@@ -1,6 +1,6 @@
 #! usr/bin/python3.6
 """
-    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445
+    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384
 
     .. warning::
         The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
@@ -13,12 +13,13 @@ from pycatia.navigator_interfaces.annotated_views import AnnotatedViews
 from pycatia.navigator_interfaces.group import Group
 from pycatia.navigator_interfaces.marker_3Ds import Marker3Ds
 from pycatia.system_interfaces.any_object import AnyObject
+from pycatia.system_interfaces.system_service import SystemService
 
 
 class Section(AnyObject):
     """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
                 |     System.IDispatch
@@ -38,10 +39,10 @@ class Section(AnyObject):
         self.section = com_object
 
     @property
-    def annotated_views(self):
+    def annotated_views(self) -> AnnotatedViews:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property AnnotatedViews() As AnnotatedViews (Read Only)
                 | 
                 |     Returns the AnnotatedViews collection of the section.
@@ -56,15 +57,16 @@ class Section(AnyObject):
                 |             Set TheAnnotatedViewsList = NewSection.AnnotatedViews
 
         :return: AnnotatedViews
+        :rtype: AnnotatedViews
         """
 
         return AnnotatedViews(self.section.AnnotatedViews)
 
     @property
-    def behavior(self):
+    def behavior(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Behavior() As CatSectionBehavior
                 | 
                 |     Returns or sets the general behavior of the section: Freeze, Automatic
@@ -91,24 +93,25 @@ class Section(AnyObject):
                 | 
                 |                 NewSection.Behavior = catSectionBehaviorAutomatic
 
-        :return: enum cat_section_behavior
+        :return: int
+        :rtype: int
         """
 
         return self.section.Behavior
 
     @behavior.setter
-    def behavior(self, value):
+    def behavior(self, value: int):
         """
-        :param enum cat_section_behavior value:
+        :param int value:
         """
 
         self.section.Behavior = value
 
     @property
-    def cut_mode(self):
+    def cut_mode(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property CutMode() As long
                 | 
                 |     Returns or sets the cutting mode of the section.
@@ -136,12 +139,13 @@ class Section(AnyObject):
                 |                 NewSection.CutMode = 1
 
         :return: int
+        :rtype: int
         """
 
         return self.section.CutMode
 
     @cut_mode.setter
-    def cut_mode(self, value):
+    def cut_mode(self, value: int):
         """
         :param int value:
         """
@@ -149,13 +153,13 @@ class Section(AnyObject):
         self.section.CutMode = value
 
     @property
-    def group(self):
+    def group(self) -> Group:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Group() As Group
                 | 
-                |     Returns or sets the sectionned group.
+                |     Returns or sets the sectioned group.
                 | 
                 |     By default, it is the all leaves group.
                 | 
@@ -163,29 +167,24 @@ class Section(AnyObject):
                 | 
                 |              The first example retrieves the group of NewSection
                 |              Section.
-                |             
-                | 
+                |
                 |             Dim AGroup As Group
                 |             AGroup = NewSection.Group
-                |             
-                | 
-                | 
-                |             
-                | 
+                |
                 |                 The second example sets the group of NewSection
                 |                 Section.
-                |                 
-                | 
+                |
                 |                 Dim AGroup As Group
                 |                 NewSection.Group = AGroup
 
         :return: Group
+        :rtype: Group
         """
 
         return Group(self.section.Group)
 
     @group.setter
-    def group(self, value):
+    def group(self, value: Group):
         """
         :param Group value:
         """
@@ -193,10 +192,10 @@ class Section(AnyObject):
         self.section.Group = value
 
     @property
-    def height(self):
+    def height(self) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Height() As double
                 | 
                 |     Returns or sets the height of the section.
@@ -223,12 +222,13 @@ class Section(AnyObject):
                 |                 NewSection.Height = 100.
 
         :return: float
+        :rtype: float
         """
 
         return self.section.Height
 
     @height.setter
-    def height(self, value):
+    def height(self, value: float):
         """
         :param float value:
         """
@@ -236,7 +236,7 @@ class Section(AnyObject):
         self.section.Height = value
 
     @property
-    def marker3_ds(self):
+    def marker_3ds(self) -> Marker3Ds:
         """
         .. note::
             CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
@@ -254,15 +254,16 @@ class Section(AnyObject):
                 |             Set TheMarker3DsList = NewSection.Marker3Ds
 
         :return: Marker3Ds
+        :rtype: Marker3Ds
         """
 
         return Marker3Ds(self.section.Marker3Ds)
 
     @property
-    def thickness(self):
+    def thickness(self) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Thickness() As double
                 | 
                 |     Returns or sets the thickness of the section.
@@ -289,12 +290,13 @@ class Section(AnyObject):
                 |                 NewSection.Thickness = 100.
 
         :return: float
+        :rtype: float
         """
 
         return self.section.Thickness
 
     @thickness.setter
-    def thickness(self, value):
+    def thickness(self, value: float):
         """
         :param float value:
         """
@@ -302,10 +304,10 @@ class Section(AnyObject):
         self.section.Thickness = value
 
     @property
-    def type(self):
+    def type(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Type() As CatSectionType
                 | 
                 |     Returns or sets the type of the section.
@@ -331,24 +333,25 @@ class Section(AnyObject):
                 | 
                 |                 NewSection.Type = catSectionTypeSlice
 
-        :return: enum cat_section_type
+        :return: int
+        :rtype: int
         """
 
         return self.section.Type
 
     @type.setter
-    def type(self, value):
+    def type(self, value: int):
         """
-        :param enum cat_section_type value:
+        :param int value:
         """
 
         self.section.Type = value
 
     @property
-    def width(self):
+    def width(self) -> float:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Width() As double
                 | 
                 |     Returns or sets the width of the section.
@@ -375,22 +378,23 @@ class Section(AnyObject):
                 |                 NewSection.Width = 100.
 
         :return: float
+        :rtype: float
         """
 
         return self.section.Width
 
     @width.setter
-    def width(self, value):
+    def width(self, value: float):
         """
         :param float value:
         """
 
         self.section.Width = value
 
-    def export(self):
+    def export(self) -> 'Document':
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func Export() As Document
                 | 
                 |     Exports the sections curves of the section in a document.
@@ -407,14 +411,15 @@ class Section(AnyObject):
                 |             PartDoc = NewSection.Export
 
         :return: Document
+        :rtype: Document
         """
         from pycatia.in_interfaces.document import Document
         return Document(self.section.Export())
 
-    def get_position(self, o_components=None):
+    def get_position(self) -> tuple:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub GetPosition(CATSafeArrayVariant oComponents)
                 | 
                 |     Retrieves the position of the section.
@@ -463,30 +468,26 @@ class Section(AnyObject):
                 |             Dim Components (11)
                 |             NewSection.GetPosition Components
 
-        :param tuple o_components:
-        :return: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.section.GetPosition(o_components)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_position'
-        # # vba_code = """
-        # # Public Function get_position(section)
-        # #     Dim oComponents (2)
-        # #     section.GetPosition oComponents
-        # #     get_position = oComponents
-        # # End Function
-        # # """
 
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_position'
+        vba_code = """
+        Public Function get_position(section)
+            Dim oComponents(11)
+            section.GetPosition oComponents
+            get_position = oComponents
+        End Function
+        """
 
-    def is_empty(self):
+        system_service = SystemService(self.application.SystemService)
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def is_empty(self) -> int:
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Func IsEmpty() As long
                 | 
                 |     Indicates whether the section is empty.
@@ -504,13 +505,14 @@ class Section(AnyObject):
                 |             Indicator = NewSection.IsEmpty
 
         :return: int
+        :rtype: int
         """
         return self.section.IsEmpty()
 
-    def set_position(self, i_components=None):
+    def set_position(self, i_components: tuple):
         """
         .. note::
-            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
+            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                 | o Sub SetPosition(CATSafeArrayVariant iComponents)
                 | 
                 |     Sets the position of the section.
@@ -568,24 +570,8 @@ class Section(AnyObject):
                 |             NewSection.SetPosition MatrixPos
 
         :param tuple i_components:
-        :return:
         """
         return self.section.SetPosition(i_components)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'set_position'
-        # # vba_code = """
-        # # Public Function set_position(section)
-        # #     Dim iComponents (2)
-        # #     section.SetPosition iComponents
-        # #     set_position = iComponents
-        # # End Function
-        # # """
-
-        # # system_service = SystemService(self.application.SystemService)
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def __repr__(self):
         return f'Section(name="{self.name}")'
